@@ -1,5 +1,5 @@
 ; Prototype to insert Lilypond Standalone Directives. Wants a pair with car Tag and cdr lilypond: (cons "BreathMark" "\\breathe")
-(define* (StandAloneDirectiveProto pair #:optional (step? #t) (graphic #f) (displaytext #f))
+(define* (StandAloneDirectiveProto pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f))
 	(d-Directive-standalone (car pair))
 	(d-DirectivePut-standalone-postfix (car pair) (cdr pair))
 	(d-DirectivePut-standalone-minpixels (car pair) 30)
@@ -10,16 +10,18 @@
 		  (d-DirectivePut-standalone-display (car pair) displaytext)
 		  (d-DirectivePut-standalone-display (car pair) (cdr pair)))
 		)
+    (if minpixels
+      (d-DirectivePut-standalone-minpixels (car pair) minpixels))
 	(if step?
 		(d-MoveCursorRight))
 	(d-RefreshDisplay))
 
 
 ; Procedure to insert Self-Editing Lilypond Standalone Directives. Takes a pair with car Tag and cdr lilypond: (cons "BreathMark" "\\breathe") with optional boolean to step right after insertion and graphic
-(define* (StandAloneSelfEditDirective pair #:optional (step? #t) (graphic #f))
+(define* (StandAloneSelfEditDirective pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f))
 	(if (d-Directive-standalone? (car pair))
 	  (d-DirectiveTextEdit-standalone (car pair))
-	  (StandAloneDirectiveProto pair step? graphic)))
+	  (StandAloneDirectiveProto pair step? graphic displaytext minpixels)))
 
 ;Wrapper to attach any lilypond directive anywhere.
 ;;Wants four strings and an arbitrary number of tags (numbers) for overrides.
@@ -196,12 +198,26 @@
 	(begin (d-DeleteObject) #t)
 	#f))
 
-(define* (ToggleChordDirective tag fontname lilypond #:optional (override #f))
+(define* (ToggleChordDirective tag fontname lilypond #:optional (override #f) (display #f))
 	(if (d-Directive-chord? tag)
           (d-DirectiveDelete-chord tag)
           (begin
-	    (d-SetSaved #f)
-            (d-DirectivePut-chord-graphic tag fontname)
+            (d-SetSaved #f)
+            (if fontname
+              (d-DirectivePut-chord-graphic tag fontname))
+            (if display
+              (d-DirectivePut-chord-display tag display))
             (d-DirectivePut-chord-postfix tag lilypond)
             (if override
 	      (d-DirectivePut-chord-override tag override)))))
+
+(define (SetDirectiveConditional)
+(define choice #f)
+(set! choice (RadioBoxMenu
+					 (cons (string-append (_ "Only for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'only)   
+					 	(cons (string-append (_ "Only for Layout \"") (d-GetLayoutName) "\"") 'default)
+					 	(cons (_ "For all Layouts") 'all)))
+				(case choice
+					((all) (d-ForAllLayouts))
+					((default) (d-OnlyForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
+					((only) (d-OnlyForLayout   (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId))))))
