@@ -98,12 +98,12 @@
 
 
 ; SetRelativeFontSize
-(define* (SetRelativeFontSize what #:optional (type "chord") (context "") (override #f))
-  (SetValue ChangeRelativeFontSize " #'font-size = #" what type context override))
+;(define* (SetRelativeFontSize what #:optional (type "chord") (context "") (override #f))
+;  (SetValue ChangeRelativeFontSize " #'font-size = #" what type context override))
 
 ; SetPadding
-(define* (SetPadding what  #:optional (type "chord") (context ""))
-  (SetValue ChangePad " #'padding = #" what type context))
+;(define* (SetPadding what  #:optional (type "chord") (context ""))
+;  (SetValue ChangePad " #'padding = #" what type context))
   
 
 
@@ -265,7 +265,7 @@ dismiss this dialog and
 simply guess at suitable points."))))
       
 					(begin
-						(d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest\n(Positioning will be done with respect to this height)"))
+						(d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest (Positioning will be done with respect to this height)"))
 						(if (d-GetReferencePoint)
 							(begin		
 								(if (and (get-control-point 1)
@@ -516,11 +516,11 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 
   
 ;;;;;;;; ChangePad
-(define (ChangePad oldstr prefixstring postfixstring)
-  (ChangeValue oldstr prefixstring postfixstring d-GetPadding "0"))
+;;;(define (ChangePad oldstr prefixstring postfixstring)
+;;;  (ChangeValue oldstr prefixstring postfixstring d-GetPadding "0"))
 ;;;;;;;; ChangeRelativeFontSize
-(define (ChangeRelativeFontSize oldstr prefixstring postfixstring)
-  (ChangeValue oldstr prefixstring postfixstring d-GetRelativeFontSize "0" DENEMO_OVERRIDE_AFFIX))
+;;;(define (ChangeRelativeFontSize oldstr prefixstring postfixstring)
+;;;  (ChangeValue oldstr prefixstring postfixstring d-GetRelativeFontSize "0" DENEMO_OVERRIDE_AFFIX))
 
 
 ;   (let ((startbit "")
