@@ -98,6 +98,18 @@ typedef struct DenemoSelection
 }
 DenemoSelection;
 
+typedef struct DenemoPalette
+{
+	gchar *name;
+	GtkWidget *box;
+	GtkWidget *window;
+	gboolean rows; /* widgets should be packed row-wise or not */
+	gint limit; /* how many widgets to pack in the chosen direction */
+	gboolean docked; /**< whether this palette is displayed in the main display */
+	GList *buttons; /**< the data are GtkWidget which have a script attached to be run when activated */
+}
+DenemoPalette;
+
 
 
 /* The idea here is to make everything recursive.  The dominant
@@ -433,7 +445,6 @@ typedef struct DenemoPrefs
   gboolean toolbar; /**< makes the toolbar visible */
   gboolean playback_controls; /**< makes the playback controls visible */
   gboolean midi_in_controls; /**< makes the midi in controls visible */
-  gboolean notation_palette; /**< makes the Note/Rest entry toolbar visible */
   gboolean rhythm_palette; /**< makes the rhythm toolbar visable */
   gboolean object_palette;  /**< makes the object menu toolbar visible */
   gboolean console_pane;  /**< makes the console pane visible */
@@ -944,7 +955,7 @@ typedef struct DenemoGUI
 
   GtkWidget *buttonboxes;/**< box for boxes showing directives */
   GtkWidget *buttonbox;/**< box for buttons accessing DenemoDirectives attached to the whole score */
-
+  GtkWidget *movements_selector; /**< box for buttons to select movements */
 
   gchar *xbm; /**< xbm representation of graphic bitmap from selected rectangle in print preview area*/
   gint xbm_width, xbm_height;/**< width and height of the xbm data */
@@ -1056,11 +1067,14 @@ struct DenemoRoot
   /* Fields used fairly directly for drawing */
   GtkWidget *page;
   GtkWidget *scorearea;
+  GtkWidget *command_manager;
   GtkAdjustment *vadjustment;
   GtkWidget *vscrollbar;
   GtkAdjustment *hadjustment;
   GtkWidget *hscrollbar;
-
+  
+  GtkWidget *hpalettes;/**< hbox holding horizontal docked palettes */
+  GtkWidget *vpalettes;/**< vbox holding vertical docked palettes */
   GtkWidget *printarea;/**< area holding a print preview */
   GtkWidget *printvscrollbar;/**< scrollbar widget for printarea */
   GtkWidget *printhscrollbar;/**< scrollbar widget for printarea */
@@ -1104,6 +1118,8 @@ struct DenemoRoot
   gboolean ScriptRecording;/**< TRUE when menuitems presses are being recorded as scheme script*/
   gint keyboard_state;/**< state of last keypress/release */
   GtkWidget *ScriptView; /**< a GtkTextView containing a scheme script */
+  GList *palettes; /**< list of palettes of buttons for activating scripts */
+  gchar *old_user_data_dir; /**< set in case of upgrading denemo version */
 }  Denemo; /**< The root object. */
 
 #endif
