@@ -24,10 +24,11 @@
 #include "midi.h"
 #include "displayanimation.h"
 #include "moveviewport.h"
+#include "audiointerface.h"
 
 #define EXCL_WIDTH 3
 #define EXCL_HEIGHT 13
-
+#define SAMPLERATE (44100) /* arbitrary large figure used if no audio */
 static GdkPixbuf *StaffPixbuf, *StaffPixbufSmall, *StaffGoBack, *StaffGoForward;
 static DenemoObject *Startobj, *Endobj;
 static gboolean layout_needed = TRUE;   //Set FALSE when further call to draw_score(NULL) is not needed.
@@ -50,8 +51,8 @@ set_start_and_end_objects_for_draw (void)
 {
   if (Denemo.gui->si->smf)
     {
-      Startobj = get_obj_for_end_time (Denemo.gui->si->smf, Denemo.gui->si->start_time - 0.001);
-      Endobj = Denemo.gui->si->end_time < 0.0 ? NULL : get_obj_for_start_time (Denemo.gui->si->smf, Denemo.gui->si->end_time - 0.001);
+      Startobj = get_obj_for_end_time (Denemo.gui->si->smf, Denemo.gui->si->start_time/get_playback_speed() + 0.001);
+      Endobj = Denemo.gui->si->end_time < 0.0 ? NULL : get_obj_for_start_time (Denemo.gui->si->smf, Denemo.gui->si->end_time/get_playback_speed() - 0.001);
     }
 }
 
@@ -142,6 +143,8 @@ struct infotopass
   gint playposition;            //x coordinate of currently played music
   gdouble leftmosttime;         //MIDI time of left most object on last system line displayed
   gdouble rightmosttime;        //MIDI time of last object  displayed
+  GList *onset;//list of note onsets when audio present
+  gint currentframe; //current frame of audio being played. (current time converted to frames (at si->audio->samplerate) and slowed down)
 };
 
 /* count the number of syllables up to staff->leftmeasurenum */
@@ -178,6 +181,13 @@ count_syllables (DenemoStaff * staff, gint from)
   return count;
 }
 
+static void draw_note_onset(cairo_t *cr, double x) 
+{
+				cairo_move_to (cr, x, 22);
+				cairo_line_to (cr, x, 0);
+				cairo_line_to (cr, x + 10, 22);
+				cairo_fill (cr);
+}
 
 /**
  *  draw_object
@@ -210,10 +220,11 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoGUI * gui, st
         cairo_fill (cr);
         cairo_restore (cr);
       }
-  //g_print("%x %f %f %f\n", Denemo.gui->si->playingnow, Denemo.gui->si->playhead,  mudelaitem->earliest_time, mudelaitem->latest_time );
+      
+      
+  //g_print("%p %p %f %f %f\n", Denemo.gui->si->playingnow, mudelaitem, Denemo.gui->si->playhead,  mudelaitem->earliest_time, mudelaitem->latest_time );
 
   // draw playhead as yellowish background
-
   if (Denemo.gui->si->playingnow == mudelaitem)
     {
       if (cr)
@@ -226,16 +237,20 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoGUI * gui, st
         }
     }
 
+  
   /* The current note, rest, etc. being painted */
 
   if (mudelaitem == Denemo.gui->si->playingnow)
     itp->playposition = x + mudelaitem->x;
 
-  if (mudelaitem == itp->startobj)
-    itp->startposition = x + mudelaitem->x + mudelaitem->minpixelsalloted;
+  if (mudelaitem == itp->startobj) {
+	
+    itp->startposition = x + mudelaitem->x/* + mudelaitem->minpixelsalloted*/;
+    // if(curobj->prev==NULL) g_print("item %p at %d\n", curobj, x+mudelaitem->x), itp->startposition -= mudelaitem->minpixelsalloted;
+	}
 
   if (mudelaitem == itp->endobj)
-    itp->endposition = x + mudelaitem->x + mudelaitem->minpixelsalloted;
+    itp->endposition = x + mudelaitem->x/* + mudelaitem->minpixelsalloted*/;
 
   /************ FIXME the drawing is side-effecting the DenemoScore si here *******************/
   if (si->currentobject == curobj)
@@ -270,6 +285,85 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoGUI * gui, st
         //g_print("highy %d\n", itp->highy);
         if ((thechord->lowesty) > itp->lowy + STAFF_HEIGHT)
           itp->lowy = thechord->lowesty - STAFF_HEIGHT;
+ 
+ //display note onsets for source audio above relevant notes in top staff.       
+         if(cr && si->audio && itp->onset) {
+			 GList *g = itp->onset;
+			
+			 gint current = mudelaitem->earliest_time*si->audio->samplerate;
+			 gint next =  mudelaitem->latest_time*si->audio->samplerate;
+			 gint leadin = 	si->audio->leadin;	 
+			 gint notewidth = 0;
+			 objnode *curobjnext = curobj->next;
+			 if(curobjnext){
+					DenemoObject *nextobj = (DenemoObject*)curobjnext->data;
+					notewidth = nextobj->x - mudelaitem->x;
+			 } else 
+			 {
+					notewidth = gui->si->measurewidth - mudelaitem->x;
+			 }
+			 /* draw the extent of the note */
+			cairo_set_source_rgba (cr, 0.0, 0.2, 1.0, 1);	
+			cairo_move_to (cr, x + mudelaitem->x, 25);
+			cairo_line_to (cr,x + mudelaitem->x, 20);
+			cairo_line_to (cr,x + mudelaitem->x+ notewidth - 2, 20);
+			cairo_line_to (cr,x + mudelaitem->x+ notewidth, 14);
+			cairo_line_to (cr,x + mudelaitem->x+ notewidth, 22);
+			cairo_line_to (cr,x + mudelaitem->x+2, 22);
+			
+			//cairo_rectangle (cr, x + mudelaitem->x, 20, notewidth, 3);
+			cairo_fill (cr);			
+			
+			cairo_set_source_rgba (cr, 0.3, 0.3, 0.3, 0.5);	
+			
+			 while( g && (((gint)g->data - leadin) < current))
+				{
+					if(itp->measurenum == 1) {//represent onsets before score starts as single red onset mark 10 pixels before the first note. test g==itp->onset to avoid re-drawing
+						cairo_save (cr);
+						cairo_set_source_rgba (cr, 1.0, 0.0, 0.0, 1.0);
+						draw_note_onset (cr, x - 10);
+						cairo_restore (cr);
+					}
+					g=g->next;
+				}
+			while( g && ((gint)g->data - leadin) < next) {
+				gdouble fraction = (((gint)g->data - leadin) - current) / (double)(next-current);
+				gint pos;
+				
+
+				
+				pos = notewidth * fraction;
+				pos +=  mudelaitem->x; 
+				if(g==si->marked_onset) {	
+					cairo_save (cr);
+					cairo_set_source_rgba (cr, 0, 0, 0, 1);
+				} else if(si->playingnow)
+				{
+					(itp->currentframe < ((gint)g->data - leadin)) ?
+						cairo_set_source_rgba (cr, 0.0, 0.2, 0.8, 0.8):
+				        cairo_set_source_rgba (cr, 0.8, 0.2, 0.0, 0.8);
+				}
+				
+				
+				draw_note_onset(cr, pos+x);
+
+				if(g==si->marked_onset) {
+					cairo_restore (cr);
+				}
+				if(si->marked_onset_position && ABS((gint)(pos + x - si->marked_onset_position))<20) {
+					si->marked_onset = g; 
+					si->marked_onset_position = 0; //g_print("Found selected onset\n\n");
+				}
+					
+				//if(g==itp->onset) g_print("First onset at %d %d %d %d\n", pos, x, si->marked_onset_position, notewidth);
+					
+				
+				g = g->next;
+			}
+			itp->onset = g;//Search onwards for future onsets. Only notes on top staff are used for display of onsets. 
+
+		 } 
+          
 
         if (itp->tupletstart)
           itp->tuplety = MAX (0, MAX (itp->tuplety, MAX (-thechord->lowesty, -thechord->highesty)));
@@ -458,7 +552,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoGUI * gui, st
   //  itp->line_end = itp->markx2 > (int)(Denemo.scorearea->allocation.width/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME));
 
 
-  itp->rightmosttime = mudelaitem->latest_time;
+  itp->rightmosttime = mudelaitem->latest_time*get_playback_speed();
 
   //g_print("returning with %d\n", itp->highy);
   /* And give a return value and we're done */
@@ -630,6 +724,8 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoGUI
               cairo_fill (cr);
             }
           itp->end = TRUE;
+          if(itp->startposition>-1 && itp->endposition<0)
+			itp->endposition = x + GPOINTER_TO_INT (itp->mwidthiterator->data) + 5;//end play marker after last note if not elsewhere
         }
       else
         {
@@ -662,7 +758,7 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoGUI * gui, struct
 
   //g_print("drawing staff %d at %d\n", itp->staffnum, y);
   gint nummeasures = g_list_length (thestaff->measures);
-
+ 
   // g_print("Of %d current %d\n", nummeasures, itp->measurenum);
   if (itp->measurenum > nummeasures)
     cr = NULL;                  //no more drawing on this staff
@@ -926,7 +1022,33 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoGUI * gui, struct
             cairo_restore (cr);
           }
 
+ 
+  
+  if(0)
+  {
+    if(gui->si->audio)      {
+            cairo_save (cr);
+            cairo_set_source_rgb (cr, 0.2, 0.7, 0.2);
+            drawnormaltext_cr (cr, _("Source Audio Attached, will play mixed with your score"), 10, 10);
+            GList *g = si->audio->onsets;
+            for(;g;g=g->next) {
+				if ( (gint)g->data > (itp->leftmosttime*si->audio->samplerate))
+					break;
+			}
+			if(g)
+				{
+					gchar * text = g_strdup_printf("First note at %f seconds", ((gint)g->data)/(double)si->audio->samplerate);
+					
+					drawnormaltext_cr (cr, text, 10, 20);
+				}
+            cairo_fill (cr);
+            cairo_restore (cr);
+            
+		}	 
+		 
+	}  
 
+  
 
   if (cr)
     cairo_restore (cr);
@@ -1079,6 +1201,8 @@ draw_score (cairo_t * cr)
   itp.endposition = -1;
   itp.startobj = itp.endobj = NULL;
   itp.tupletstart = itp.tuplety = 0;
+  itp.onset = si->audio?si->audio->onsets:NULL;
+  itp.currentframe = (get_playback_time()/get_playback_speed())*(si->audio?si->audio->samplerate:SAMPLERATE);
   y = 0;
 
   if (gui->si->smf)
@@ -1099,8 +1223,7 @@ draw_score (cairo_t * cr)
     cairo_scale (cr, gui->si->zoom, gui->si->zoom);
   if (cr)
     cairo_translate (cr, 0.5, 0.5);
-  //cairo_rotate( cr, M_PI/6.0 );
-
+ 
   /* Draw each staff */
   for (itp.staffnum = si->top_staff, curstaff = g_list_nth (si->thescore, si->top_staff - 1), (y += si->staffspace / 4); curstaff && itp.staffnum <= si->bottom_staff; itp.staffnum++)
     {
@@ -1232,7 +1355,7 @@ draw_score (cairo_t * cr)
       if (draw_staff (flip_count > 0 ? NULL : cr, curstaff, y, gui, &itp))
         repeat = TRUE;
 
-      if (cr)
+      if (cr) 
         draw_playback_markers (cr, &itp, y, line_height);
 
       gint system_num;
@@ -1344,6 +1467,7 @@ draw_score (cairo_t * cr)
   //g_print("Right most time %f\n", si->rightmost_time);
   //  if(itp.last_midi)
   //  si->rightmost_time = get_midi_off_time(itp.last_midi);
+ 
 
   return repeat;
 
@@ -1374,7 +1498,11 @@ draw_callback (cairo_t * cr)
       }
   layout_needed = TRUE;
 
-
+ if( gui->si->audio && (gui->si->smfsync != gui->si->changecount) && (!audio_is_playing())) 
+ {
+	 set_tempo ();
+	 exportmidi (NULL, gui->si, 0, 0);  
+ }
   /* Clear with an appropriate background color. */
   if (Denemo.gui->input_source != INPUTKEYBOARD && Denemo.gui->input_source != INPUTMIDI && (Denemo.prefs.overlays || (Denemo.gui->input_source == INPUTAUDIO)) && pitch_entry_active (gui))
     {
