@@ -7,12 +7,8 @@
  *
  */
 void
-draw_fakechord (cairo_t *cr,
-	     gint xx, gint y, DenemoObject * theobj)
+draw_fakechord (cairo_t * cr, gint xx, gint y, DenemoObject * theobj)
 {
-  gchar *text = NULL;
-  GString *temp = g_string_new("");
-  gint length = 0;
   chord *ch;
   if (theobj->type == FAKECHORD)
     {
@@ -21,8 +17,6 @@ draw_fakechord (cairo_t *cr,
   else if (theobj->type == CHORD)
     {
       ch = (chord *) theobj->object;
-      drawnormaltext_cr( cr,  ((GString *) ch->fakechord)->str, xx, y + STAFF_HEIGHT - 10 );
+      drawnormaltext_cr (cr, ((GString *) ch->fakechord)->str, xx, y + STAFF_HEIGHT - 10);
     }
 }
-
-
