@@ -80,7 +80,8 @@ draw_notehead (cairo_t * cr,
                DenemoGraphic * override_notehead, 
                gint gx, 
                gint gy, 
-               gboolean at_cursor)
+               gboolean at_cursor,
+               gboolean percussion)
 {
   /* Adam's changed this code; it used to be that these arrays only had
      three elements.  The change has defeated what had been semi-elegance;
@@ -121,7 +122,7 @@ draw_notehead (cairo_t * cr,
      done before xx is modified, as the the value in
      position_of_accidental already accounts for any reverse-alignment
      in the chord.  */
-  if (thenote->showaccidental)
+  if (thenote->showaccidental && !percussion)
     {
       if (cr)
         {
@@ -374,7 +375,7 @@ draw_chord (cairo_t * cr, objnode * curobj, gint xx, gint y, gint mwidth, gint *
           for (curnode = thechord.notes; curnode; curnode = curnode->next)
             {
               note *thenote = (note *) curnode->data;
-              draw_notehead (cr, thenote, duration, thechord.numdots, xx, y, accs, thechord.is_stemup, override_notehead, gx, gy, at_cursor);
+              draw_notehead (cr, thenote, duration, thechord.numdots, xx, y, accs, thechord.is_stemup, override_notehead, gx, gy, at_cursor, mudelaitem->isinvisible);
             }
         }
     }
