@@ -57,9 +57,9 @@ fluidsynth_init (DenemoPrefs * config, unsigned int samplerate)
   if (sfont_id == -1)
     {
       g_debug ("Failed to load the user soundfont. Now trying the default soundfont.");
-      gchar *default_soundfont = find(SOUNDFONTS, "A320U.sf2");
-
-      sfont_id = fluid_synth_sfload (synth, default_soundfont, FALSE);
+      gchar *default_soundfont = find_denemo_file(DENEMO_DIR_SOUNDFONTS, "A320U.sf2");
+	  if(default_soundfont)
+		sfont_id = fluid_synth_sfload (synth, default_soundfont, FALSE);
       g_free (default_soundfont);
     }
   if (sfont_id == -1)
