@@ -704,7 +704,7 @@ static gint
 command_iter_sort (GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b, G_GNUC_UNUSED gpointer user_data)
 {
   GtkTreeIter *iters[2];
-  KeymapCommandType type;
+ // KeymapCommandType type;
   gpointer action;
   const gchar *names[2];
   gint i;
@@ -712,11 +712,11 @@ command_iter_sort (GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b, G_GNU
   iters[1] = b;
   for (i = 0; i < 2; i++)
     {
-      gtk_tree_model_get (model, iters[i], COL_TYPE, &type, COL_ACTION, &action, -1);
-
-      names[i] = gtk_action_get_name (action);
+     // gtk_tree_model_get (model, iters[i], /*COL_TYPE, &type,*/ COL_ACTION, &action, -1);
 
+     // names[i] = gtk_action_get_name (action);
 
+	gtk_tree_model_get (model, iters[i], COL_LABEL, names+i, -1);
     }
   return strcmp (names[0], names[1]);
 }
@@ -724,7 +724,6 @@ command_iter_sort (GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b, G_GNU
 void
 alphabeticalize_commands (keymap * the_keymap)
 {
-  // return;
   g_print ("alphabeticalizing the commands");
   gint i, n;
   guint *value;
@@ -1129,8 +1128,13 @@ update_accel_labels (keymap * the_keymap, guint command_idx)
         *c = '-';
     }
 #endif
-  gchar *markup = g_strdup_printf ("%s <span style=\"italic\" stretch=\"condensed\" weight=\"bold\" foreground=\"blue\">%s</span>", base, str->str);
-
+  gchar *escape_base = g_markup_escape_text(base, -1);
+  gchar *markup;
+  if(str->len)
+	markup = g_strdup_printf ("%s <span style=\"italic\" stretch=\"condensed\" weight=\"bold\" foreground=\"blue\">%s</span>", escape_base, str->str);
+  else
+	markup = g_strdup (escape_base);
+  g_free (escape_base);
 
   action = gtk_action_group_get_action (Denemo.action_group, command_name);
   //For all widgets proxying the action, change the label
@@ -1312,6 +1316,7 @@ add_named_binding_to_idx (keymap * the_keymap, gchar * kb_name, guint command_id
   old_command_idx = lookup_command_for_keybinding_name (the_keymap, kb_name);   //lookup_keybinding(the_keymap, keyval, state);  
   gchar *title = NULL;
   gchar *prompt = NULL;
+
   if (old_command_idx >= 0)
     {
       if ((!Denemo.prefs.return_key_is_special) || strcmp (kb_name, "Return"))
@@ -1565,7 +1570,7 @@ get_user_keymap_dir ()
   gboolean err;
   if (!keymapdir)
     {
-      keymapdir = g_build_filename (get_user_data_dir (), COMMANDS_DIR, NULL);
+      keymapdir = g_build_filename (get_user_data_dir (TRUE), COMMANDS_DIR, NULL);
     }
   err = g_mkdir_with_parents (keymapdir, 0770);
   if (err)
@@ -1613,7 +1618,7 @@ show_type (GtkWidget * widget, gchar * message)
  * a user dialog. 
  */
 void
-load_keymap_dialog_location (GtkWidget * widget, gchar * location)
+load_keymap_dialog_location (gchar * location)
 {
   gchar *filename = file_dialog ("Load Command Set", TRUE, location);
   if (filename)
@@ -1621,23 +1626,23 @@ load_keymap_dialog_location (GtkWidget * widget, gchar * location)
 }
 
 void
-load_keymap_dialog (GtkWidget * widget)
+load_keymap_dialog ()
 {
   gchar *keymapdir = g_strdup_printf ("%s%c", get_user_keymap_dir (), G_DIR_SEPARATOR);
   if (keymapdir)
-    load_keymap_dialog_location (widget, keymapdir);
+    load_keymap_dialog_location (keymapdir);
   else
     warningdialog (_("Cannot access your local .denemo"));
   g_free (keymapdir);
 }
 
 void
-load_system_keymap_dialog (GtkWidget * widget)
+load_system_keymap_dialog (void)
 {
   gchar *systemwide = g_build_filename (get_system_data_dir (), COMMANDS_DIR, USER_KEYMAP, KEYMAP_EXT,
                                         NULL);
   if (systemwide)
-    load_keymap_dialog_location (widget, systemwide);
+    load_keymap_dialog_location (systemwide);
   else
     warningdialog (_("Installation error"));
   g_free (systemwide);
@@ -1648,8 +1653,13 @@ load_default_keymap_file ()
 {
   gchar* user_keymap_file = g_strconcat (USER_KEYMAP, KEYMAP_EXT, NULL);
   gchar* default_keymap_file = g_strconcat (DEFAULT_KEYMAP, KEYMAP_EXT, NULL);
-
+  gchar *upgrade = NULL;
+  if(Denemo.old_user_data_dir) 
+	{
+	 upgrade = g_build_filename (Denemo.old_user_data_dir, COMMANDS_DIR, user_keymap_file, NULL);
+	}
   gchar* files[] = {
+    g_build_filename (g_get_current_dir (), COMMANDS_DIR, user_keymap_file, NULL),
     g_build_filename (get_user_keymap_dir (), user_keymap_file, NULL),
     g_build_filename (get_system_data_dir (), COMMANDS_DIR, user_keymap_file, NULL),
     g_build_filename (get_user_keymap_dir (), default_keymap_file, NULL),
@@ -1659,7 +1669,16 @@ load_default_keymap_file ()
 
   if(!load_keymap_files (files))
     g_warning ("Unable to load default keymap");
-  
+    
+    
+  if(upgrade) {
+	gchar* files[] = {
+		upgrade,
+		NULL
+	};
+    if(!load_keymap_files (files))
+    g_warning ("Unable to former default keymap");
+  }
   g_free(default_keymap_file);
   g_free (user_keymap_file);
 }
@@ -1718,7 +1737,7 @@ save_keymap_from_dialog (gchar * filename)
  * a user dialog.  Similar to file_saveas. 
  */
 void
-save_keymap_dialog (GtkWidget * widget)
+save_keymap_dialog (void)
 {
   gchar *keymapdir = NULL;
   keymapdir = g_build_filename (get_user_keymap_dir (), NULL);
@@ -1804,6 +1823,13 @@ command_name_data_function (G_GNUC_UNUSED GtkTreeViewColumn * col, GtkCellRender
 
   g_object_set (renderer, "text", name, NULL);
 }
+static void
+label_data_function (G_GNUC_UNUSED GtkTreeViewColumn * col, GtkCellRenderer * renderer, GtkTreeModel * model, GtkTreeIter * iter, G_GNUC_UNUSED gpointer user_data)
+{
+  const gchar *name;
+  gtk_tree_model_get (model, iter, COL_LABEL, &name, -1);
+  g_object_set (renderer, "text", name, NULL);
+}
 
 static void
 command_hidden_data_function (G_GNUC_UNUSED GtkTreeViewColumn * col, GtkCellRenderer * renderer, GtkTreeModel * model, GtkTreeIter * iter, G_GNUC_UNUSED gpointer user_data)
@@ -1828,21 +1854,41 @@ command_deleted_data_function (GtkTreeViewColumn * col, GtkCellRenderer * render
   g_object_set (renderer, "active", deleted, NULL);
 }
 */
+static gboolean search_tooltip=1;//implemented as searching substrings in tooltip, could be a level of match, for number of words present in tooltip & label
+static gint last_idx=-1;//implemented as last found idx
 static gboolean
 search_equal_func (GtkTreeModel * model, gint G_GNUC_UNUSED column, const gchar * key, GtkTreeIter * iter, G_GNUC_UNUSED gpointer search_data)
 {
-  KeymapCommandType type;
-  gpointer action;
-  const gchar *name;
-  gboolean res;
-  gchar *name_trunk;
-  gtk_tree_model_get (model, iter, COL_TYPE, &type, COL_ACTION, &action, -1);
-  name = gtk_action_get_name (action);
 
-  name_trunk = g_strndup (name, strlen (key));
-  res = strcmp (name_trunk, key) == 0;
-  g_free (name_trunk);
-  return !res;
+  gchar *lookin;
+  gchar *name;
+  gboolean notfound;
+  if(search_tooltip)
+   gtk_tree_model_get (model, iter, COL_TOOLTIP, &lookin, -1);
+  else
+   gtk_tree_model_get (model, iter, COL_LABEL, &lookin, -1);
+  gchar *this, *that;
+  this = g_utf8_casefold (lookin, -1);
+  that =  g_utf8_casefold (key, -1);
+  if(search_tooltip)
+  {
+	  
+	  gtk_tree_model_get (model, iter, COL_NAME, &name, -1);
+	  const gint idx = lookup_command_from_name(Denemo.map, name);//= lookup_action_from_name (name);
+	  notfound = (NULL == g_strstr_len (this, -1, that));
+	  if((!notfound) && (idx <= last_idx))
+		notfound = TRUE;
+	  if(!notfound) 
+			last_idx = idx;
+  } 
+  else
+  {	
+    notfound = (strcmp (this, that) < 0);
+  }
+  g_free(this);
+  g_free(that);
+  //g_free (lookin); The doc says that name should be freed, but two calls in succession yield the same pointer.
+  return notfound;
 }
 
 /*toggle hidden on action at row in command list */
@@ -1873,8 +1919,37 @@ toggle_deleted_on_action (GtkCellRendererToggle * cell_renderer, gchar * path)
     }
 }
 */
+extern GtkWidget *get_command_view();
+static void
+search_next (GtkWidget *SearchEntry)
+{
+	if ( gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(get_command_view())), NULL, NULL))
+		;//last_idx++;
+	else
+		last_idx = -1;
+  //FIXME issue some signal to cause a search to be made
+  g_signal_emit_by_name (SearchEntry, "insert-at-cursor", "");
+  gtk_widget_grab_focus (SearchEntry);
+}
+static void toggle_tooltip_search (void)
+{
+	search_tooltip = !search_tooltip;
+}
+static void selection_changed (GtkTreeSelection *selection, GtkWidget *SearchEntry) {
+	gint command_idx;
+	
+	GtkTreeModel *model = GTK_TREE_MODEL (Denemo.map->commands);
+	
+	GtkTreeIter iter = { 0, NULL, NULL, NULL };
+	const gchar *command_name;
+	if(gtk_tree_selection_get_selected (selection, NULL, &iter))
+	  {
+		gtk_tree_model_get (model, &iter, COL_NAME, &command_name, -1);
+		last_idx = lookup_command_from_name(Denemo.map, command_name);
+	  }
+}
 GtkWidget *
-keymap_get_command_view (keymap * the_keymap)
+keymap_get_command_view (keymap * the_keymap, GtkWidget *SearchEntry, GtkWidget *SearchNext)
 {
   GtkScrolledWindow *res2;
   GtkTreeView *res;
@@ -1886,8 +1961,21 @@ keymap_get_command_view (keymap * the_keymap)
   model = GTK_TREE_MODEL (the_keymap->commands);
   //setting up the tree view
   res = GTK_TREE_VIEW (gtk_tree_view_new ());
+
+  
   gtk_tree_view_set_model (res, model);
 
+
+  col = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_title (col, _("Command"));
+  gtk_tree_view_append_column (res, col);
+
+  renderer = gtk_cell_renderer_text_new ();
+  gtk_tree_view_column_pack_start (col, renderer, TRUE);
+  gtk_tree_view_column_set_cell_data_func (col, renderer, label_data_function, NULL, NULL);
+
+#if 0
+/* including this column makes the command manager too wide */
   col = gtk_tree_view_column_new ();
   gtk_tree_view_column_set_title (col, _("Commands"));
   gtk_tree_view_append_column (res, col);
@@ -1895,7 +1983,7 @@ keymap_get_command_view (keymap * the_keymap)
   renderer = gtk_cell_renderer_text_new ();
   gtk_tree_view_column_pack_start (col, renderer, TRUE);
   gtk_tree_view_column_set_cell_data_func (col, renderer, command_name_data_function, NULL, NULL);
-
+#endif
   col = gtk_tree_view_column_new ();
   gtk_tree_view_column_set_title (col, _("Hidden"));
   gtk_tree_view_append_column (res, col);
@@ -1922,9 +2010,15 @@ keymap_get_command_view (keymap * the_keymap)
 
   selection = gtk_tree_view_get_selection (res);
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
+  
+  g_signal_connect (G_OBJECT(selection),  "changed", G_CALLBACK(selection_changed), (gpointer)SearchEntry);
+  
   gtk_tree_view_set_search_equal_func (res, search_equal_func, NULL, NULL);
+//gtk_tree_view_set_search_column (res, COL_LABEL);
   gtk_tree_view_set_enable_search (res, TRUE);
 
+
+
   //setting up the scrolledwindow
   res2 = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
   gtk_container_add (GTK_CONTAINER (res2), GTK_WIDGET (res));
@@ -1932,6 +2026,28 @@ keymap_get_command_view (keymap * the_keymap)
 
   //FIXME adapt so that 10~15 rows are visible
   gtk_widget_set_size_request (GTK_WIDGET (res2), -1, 300);
+  
+  GtkWidget *vbox = gtk_vbox_new (FALSE, 8);
+  GtkWidget *hbox = gtk_hbox_new (FALSE, 8);
+
+  gtk_tree_view_set_search_entry (res, SearchEntry);
+  GtkWidget *label = gtk_label_new (_("Search"));
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), SearchEntry, FALSE, TRUE, 0);
+  
+  gtk_box_pack_start (GTK_BOX (hbox), SearchNext, FALSE, TRUE, 0);
+
+  GtkWidget *toggle = gtk_check_button_new_with_label (_("Search in tooltip"));
+  gtk_toggle_button_set_active (toggle, TRUE);
+  gtk_widget_set_can_focus (toggle, FALSE);
+  g_signal_connect(G_OBJECT(toggle), "toggled", G_CALLBACK(toggle_tooltip_search), NULL);
+  gtk_box_pack_end (GTK_BOX (hbox), toggle, FALSE, TRUE, 0);
+  
+  g_signal_connect_swapped (G_OBJECT (SearchNext), "clicked", G_CALLBACK (search_next), SearchEntry);
+  
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), res2, TRUE, TRUE, 0);
+		
 
   return GTK_WIDGET (res2);
 }
@@ -1955,17 +2071,58 @@ row_deleted_handler (GtkTreeModel * model, GtkTreePath * arg1, gpointer user_dat
 }
 
 //Performs cleanup on the keymap when a command view is closed
-void
+gboolean
 keymap_cleanup_command_view (keyboard_dialog_data * data)
 {
+#if 0
   GtkTreeModel *model;
   model = gtk_tree_view_get_model (data->binding_view);
   if (model)
     {
       g_signal_handlers_disconnect_by_func (model, row_deleted_handler, data);
     }
+
+   Denemo.command_manager = NULL;
+   return FALSE;//allow window to be destroyed
+#endif   
+   activate_action ("/MainMenu/ViewMenu/" "ToggleCommandManager");
+  return TRUE; 
+   
+}
+const gchar *
+get_menu_label (gchar *name)
+{ const gchar *label = NULL;
+  GtkAction *action = gtk_action_group_get_action (Denemo.action_group, name);
+  if(action) 
+  {
+	label = gtk_action_get_label (action);
+
+   }
+ if(!label) 
+		label = name;
+ return label;  
 }
 
+/* caller must free */
+gchar *get_menu_position (gchar *menupath)
+ {
+	 if(menupath==NULL)
+		menupath = g_strdup(_("Built-in, see file denemoui.xml for position"));
+	 GString *position = g_string_new("");
+	 gchar *path = g_strdup(menupath/* + 1 skip over the initial delimeter*/);
+	 gchar *element = strtok (path, "/");
+	 if(element) {
+		g_string_append (position, get_menu_label(element));
+		while ((element = strtok (NULL, "/"))) {
+			if(*element)
+				g_string_append_printf (position, "->%s", get_menu_label(element));	
+			else
+				g_string_append	 (position, "**");
+			}
+	}
+	g_free(path);
+	return g_string_free (position, FALSE);  
+  }
 gboolean
 keymap_change_binding_view_on_command_selection (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, gpointer data)
 {
@@ -2015,10 +2172,14 @@ keymap_change_binding_view_on_command_selection (GtkTreeSelection * selection, G
   if (tooltip)
     {
       gchar *plain;
-      pango_parse_markup (tooltip, -1, 0, NULL, &plain, 0, NULL);
-
+      gchar *menupath = get_menu_position (g_object_get_data (G_OBJECT (action), "menupath"));
+      
+	  gchar *text = g_strdup_printf (_( "%s\nLocation: %s\nInternal Name: %s"), tooltip, menupath, gtk_action_get_name(action));
+      pango_parse_markup (text, -1, 0, NULL, &plain, 0, NULL);
+	  g_free(text);
       gtk_text_buffer_set_text (text_buffer, plain, -1);
       g_free (plain);
+      g_free(menupath);
     }
   //perform the selection
   return TRUE;
