@@ -128,25 +128,25 @@ gboolean idx_has_callback (keymap * the_keymap, guint command_idx);
 
 void dump_command_info (keymap * the_keymap, gint command_idx);
 guint dnm_sanitize_key_state (GdkEventKey * event);
-void load_keymap_dialog (GtkWidget * Widget);
+void load_keymap_dialog (void);
 
 
 void load_default_keymap_file (void);
 
-void load_system_keymap_dialog (GtkWidget * widget);
-void save_keymap_dialog (GtkWidget * widget);
-void load_keymap_dialog_location (GtkWidget * widget, gchar * location);
+void load_system_keymap_dialog (void);
+void save_keymap_dialog (void);
+void load_keymap_dialog_location (gchar * location);
 void save_default_keymap_file_wrapper (GtkAction * action, gpointer param);
 
 void save_default_keymap_file (void);
 
 void set_state (gint state, gchar ** value);
 
-GtkWidget *keymap_get_command_view (keymap * the_keymap);
+GtkWidget *keymap_get_command_view (keymap * the_keymap, GtkWidget *entry, GtkWidget *next);
 
 GtkWidget *keymap_get_binding_view ();
 
-void keymap_cleanup_command_view (keyboard_dialog_data * data);
+gboolean keymap_cleanup_command_view (keyboard_dialog_data * data);
 
 gboolean keymap_change_binding_view_on_command_selection (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, gpointer data);
 
@@ -165,4 +165,6 @@ void command_row_init(command_row *command);
 gboolean keymap_get_command_row (keymap * the_keymap, command_row * row, guint command_idx);
 gboolean is_action_id_builtin(gint id);
 gboolean is_action_name_builtin(gchar* command_name);
+const gchar *get_menu_label (gchar *name);
+gchar *get_menu_position (gchar *menupath);
 #endif
