@@ -224,6 +224,20 @@ kbd_interface_del_binding (G_GNUC_UNUSED GtkButton * button, gpointer user_data)
   g_free (binding);
   Denemo.accelerator_status = TRUE;
 }
+static void
+execute_current (keyboard_dialog_data *data)
+{
+	//FIXME if recording, record to scheme window
+ execute_callback_from_idx (Denemo.map, data->command_idx);
+}
+static void
+add_current_to_palette (keyboard_dialog_data *data)
+{
+ place_action_in_palette (data->command_idx, NULL);
+}
+
+
+
 
 typedef struct ModifierPointerInfo
 {
@@ -278,26 +292,35 @@ button_choice_callback (GtkWidget * w, gint * mask)
   g_print ("button choice %x\n", *mask);
 }
 
-#define RESPONSE_LOADED (1)
+
 static void
-load_system_keymap_dialog_response (GtkButton * button, GtkWidget * dialog)
+load_system_keymap_dialog_response (void)
 {
-  load_system_keymap_dialog (GTK_WIDGET (button));
-  gtk_dialog_response (GTK_DIALOG (dialog), RESPONSE_LOADED);
+  load_system_keymap_dialog ();
+  
 }
 
 static void
-load_keymap_dialog_response (GtkButton * button, GtkWidget * dialog)
+load_keymap_dialog_response (void)
 {
-  load_keymap_dialog (GTK_WIDGET (button));
-  gtk_dialog_response (GTK_DIALOG (dialog), RESPONSE_LOADED);
+  load_keymap_dialog ();
+  
 }
 
+static GtkWidget *SearchEntry = NULL;
+static GtkWidget *SearchNext = NULL;
+
+static  keyboard_dialog_data cbdata;
+
+GtkWidget *get_command_view(void)
+{
+return	cbdata.command_view;
+}
 
 void
 configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
 {
-  GtkWidget *dialog;
+  
   GtkWidget *frame;
   GtkWidget *vbox, *outer_hbox;
   GtkWidget *table;
@@ -324,32 +347,65 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   GtkTreeModel *model;
   GtkTreePath *path;
   guint context_id;
-  keyboard_dialog_data cbdata;
-
+ 
+  if(Denemo.command_manager)   {
+	  model = gtk_tree_view_get_model (GTK_TREE_VIEW (cbdata.command_view));
+	  if (command_idx == -1)
+		{
+		//selecting the first command
+		gtk_tree_model_get_iter_first (model, &iter);
+		} 
+	  else
+		{
+			gtk_tree_model_iter_nth_child (model, &iter, NULL, command_idx);
+		}
+	  gtk_widget_grab_focus (SearchEntry);
+	  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (cbdata.command_view));
+      gtk_tree_selection_select_iter (selection, &iter);
+      path = gtk_tree_model_get_path (model, &iter);
+      gtk_tree_view_scroll_to_cell ((GtkTreeView *) cbdata.command_view, path, NULL, FALSE, 0, 0);
+      gtk_tree_path_free (path);
+      if(!gtk_widget_get_visible(Denemo.command_manager))
+		activate_action ("/MainMenu/ViewMenu/" "ToggleCommandManager");
+      return;
+    }
+   if(SearchEntry==NULL) {
+	SearchEntry = gtk_entry_new ();
+	SearchNext = gtk_button_new_with_label ("->");
+	
+}   
   //getting a binding view and a command view and connecting the change of
   //command selection the the change of the model displayed by the binding view
   binding_view = keymap_get_binding_view ();
   binding_tree_view = gtk_bin_get_child (GTK_BIN (binding_view));
-  command_view = GTK_WIDGET (keymap_get_command_view (Denemo.map));
+  command_view = GTK_WIDGET (keymap_get_command_view (Denemo.map, SearchEntry, SearchNext));
   command_tree_view = gtk_bin_get_child (GTK_BIN (command_view));
 
-  dialog = gtk_dialog_new_with_buttons (_("Command Manager"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+  Denemo.command_manager = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title(GTK_WINDOW(Denemo.command_manager), (_("Command Center")));
   if (Denemo.prefs.newbie)
-    gtk_widget_set_tooltip_text (dialog,
+    gtk_widget_set_tooltip_text (Denemo.command_manager,
                                  _
-                                 ("This dialog allows you to set shortcuts for commands. As there are so many commands it is best to launch the dialog from the command that you wish to change.\n(Do this by right clicking on the menu item of the command\nthis dialog then comes up with the command highlighted).\nYou can set single-key or two-key shortcuts, or mouse shortcuts.\nYou can also hide commands, so they don't appear in the menus.\nWhen you are finished you can save the settings as your default command set, or as a command set which you may wish to load in the future.\nThis dialog is also where you can load such a stored command set."));
+                                 ("This window allows you find and execute commands.\nOnce you have selected a command the box at the top gives information about that command,"
+                                 "\nwhile the panel to the side gives any shortcuts for the command"
+                                 "\nyou can add a selected command to a palette, or set single-key or two-key shortcuts."
+                                 "\nYou can also hide commands, so they don't appear in the menus.\n"
+                                 "You can save the shortcuts as your default command set, or as a command set which you may wish to load in the future.\n"
+                                 "This window is also where you can load such a stored command set."));
 
   outer_hbox = gtk_hbox_new (FALSE, 8);
+  gtk_container_add (GTK_CONTAINER (Denemo.command_manager), outer_hbox);
   vbox = gtk_vbox_new (FALSE, 8);
-  GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-  gtk_container_add (GTK_CONTAINER (content_area), outer_hbox);
+   
+  
+
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_box_pack_start (GTK_BOX (outer_hbox), vbox, TRUE, TRUE, 0);
 
-
+	
   frame = gtk_frame_new (_("Help for Selected Command"));
   gtk_frame_set_shadow_type ((GtkFrame *) frame, GTK_SHADOW_IN);
-  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
   text_view = gtk_text_view_new ();
   gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), FALSE);
   scrolled_text_view = gtk_scrolled_window_new (NULL, NULL);
@@ -357,46 +413,19 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_text_view), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_add (GTK_CONTAINER (frame), scrolled_text_view);
 
-  //  gtk_box_pack_start (GTK_BOX (vbox), scrolled_text_view, TRUE, TRUE, 0);
-
-
-
-
-  table = gtk_table_new (2, 2, FALSE);
-  gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 8);
-
-  button_save = gtk_button_new_with_label (_("Save as Default Command Set"));
-  gtk_table_attach (GTK_TABLE (table), button_save, 0, 1, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-  gtk_widget_set_tooltip_text (button_save, _("Use this to save the changes you have made so that they are used every time you start Denemo. The changes are stored under a directory (folder) called .denemo-* in your home directory. Look in subdirectory actions for Default.commands"));
-  button_save_as = gtk_button_new_with_label (_("Save as a Custom Command Set"));
-  gtk_table_attach (GTK_TABLE (table), button_save_as, 1, 2, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  button_load = gtk_button_new_with_label (_("Load a Standard Command Set"));
-  gtk_table_attach (GTK_TABLE (table), button_load, 0, 1, 0, 1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  button_load_from = gtk_button_new_with_label (_("Load a Custom Command Set"));
-  gtk_table_attach (GTK_TABLE (table), button_load_from, 1, 2, 0, 1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  table = gtk_table_new (6, 6, FALSE);
-  gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 8);
-
-  gtk_table_attach (GTK_TABLE (table), command_view, 0, 3, 0, 6, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-  gtk_table_attach (GTK_TABLE (table), binding_view, 3, 6, 0, 5, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-/*   addbutton = gtk_button_new_from_stock (GTK_STOCK_ADD); */
-/*   gtk_table_attach (GTK_TABLE (table), addbutton, 3, 4, 5, 6, */
-/* 		    (GtkAttachOptions) (GTK_FILL), */
-/* 		    (GtkAttachOptions) (0), 0, 0); */
 
+  {
+  GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (inner_hbox), gtk_widget_get_parent(command_view), TRUE, TRUE, 0);
+  {
+    GtkWidget *inner_vbox = gtk_vbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (inner_hbox), inner_vbox,  TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (inner_vbox), binding_view,  TRUE, TRUE, 0);
   delbutton = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-  //gtk_widget_set_sensitive (delbutton, FALSE);
-  gtk_table_attach (GTK_TABLE (table), delbutton, 4, 5, 5, 6, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-
+    gtk_box_pack_start (GTK_BOX (inner_vbox), delbutton, FALSE, TRUE, 0);
+}
+  }
   //lookbutton = gtk_button_new_from_stock (GTK_STOCK_FIND);
   // gtk_table_attach (GTK_TABLE (table), lookbutton, 5, 6, 5, 6,
 //                  (GtkAttachOptions) (GTK_FILL),
@@ -404,23 +433,63 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
 
   vbox = gtk_vbox_new (FALSE, 8);
   gtk_box_pack_end (GTK_BOX (outer_hbox), vbox, FALSE, TRUE, 0);
+  
+   {
+  GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
+   button_save = gtk_button_new_with_label (_("Save as Default Command Set"));
+	gtk_box_pack_start (GTK_BOX (inner_hbox), button_save, FALSE, TRUE, 0);
+  gtk_widget_set_tooltip_text (button_save, _("Use this to save the changes you have made so that they are used every time you start Denemo. The changes are stored under a directory (folder) called .denemo-* in your home directory. Look in subdirectory actions for Default.commands"));
+  button_save_as = gtk_button_new_with_label (_("Save as a Custom Command Set"));
+	gtk_box_pack_start (GTK_BOX (inner_hbox), button_save_as, FALSE, TRUE, 0);
+
+  button_load = gtk_button_new_with_label (_("Load a Standard Command Set"));
+	inner_hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
+    button_load = gtk_button_new_with_label (_("Load a Standard Command Set"));
+  	gtk_box_pack_start (GTK_BOX (inner_hbox), button_load, FALSE, TRUE, 0);
+
+  button_load_from = gtk_button_new_with_label (_("Load a Custom Command Set"));
+  	gtk_box_pack_start (GTK_BOX (inner_hbox), button_load_from, FALSE, TRUE, 0);
+
+   }
+  
+  GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 1);
+  gtk_box_pack_end (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
+    GtkWidget *inner_vbox = gtk_vbox_new (FALSE, 1);
+  gtk_box_pack_end (GTK_BOX (inner_hbox), inner_vbox, FALSE, TRUE, 0);
   addbutton = gtk_button_new_from_stock (GTK_STOCK_ADD);
   gtk_button_set_label (GTK_BUTTON (addbutton), _("Add 1-Key Shortcut"));
   gtk_widget_set_tooltip_text (addbutton, _("Create a single keypress (with modifier keys - Control, Shift ... - if needed) as a keyboard shortcut for the currently selected command."));
-  gtk_box_pack_end (GTK_BOX (vbox), addbutton, FALSE, TRUE, 0);
-
-
+  gtk_box_pack_end (GTK_BOX (inner_vbox), addbutton, FALSE, TRUE, 0);
 
   add2button = gtk_button_new_from_stock (GTK_STOCK_ADD);
   gtk_button_set_label (GTK_BUTTON (add2button), _("Add 2-Key Shortcut"));
   gtk_widget_set_tooltip_text (add2button, _("Create a two keypress sequence as a keyboard shortcut for the currently selected command."));
-  gtk_box_pack_end (GTK_BOX (vbox), add2button, FALSE, TRUE, 0);
+  gtk_box_pack_end (GTK_BOX (inner_vbox), add2button, FALSE, TRUE, 0);
 
   lookbutton = gtk_button_new_from_stock (GTK_STOCK_FIND);
-  gtk_button_set_label (GTK_BUTTON (lookbutton), _("Find "));
-  gtk_widget_set_tooltip_text (lookbutton, _("Finds the command (if any) for a Keyboard Shortcut\nClick button then press the key shortcut you are looking for"));
-  gtk_box_pack_end (GTK_BOX (vbox), lookbutton, FALSE, TRUE, 0);
+  gtk_button_set_label (GTK_BUTTON (lookbutton), _("Find Command for Shortcut"));
+  gtk_widget_set_tooltip_text (lookbutton, _("Finds the command (if any) for a (one key) Keyboard Shortcut\n"
+											  "Click button then press the key shortcut you are looking for."));
+  gtk_box_pack_end (GTK_BOX (inner_vbox), lookbutton, FALSE, TRUE, 0);
 
+
+  inner_vbox = gtk_vbox_new (FALSE, 1);
+  gtk_box_pack_start (GTK_BOX (inner_hbox), inner_vbox, FALSE, TRUE, 0);
+  GtkWidget *execute_button = gtk_button_new_with_label (_("Execute Selected Command"));
+  gtk_widget_set_tooltip_text (execute_button, _("Executes the currently selected command in the list of commands\nEnsure the cursor is in the movement and at the position if needed for the command."));
+  gtk_box_pack_end (GTK_BOX (inner_vbox), execute_button, FALSE, TRUE, 0);
+  GtkWidget *palette_button = gtk_button_new_with_label (_("Add to Palette"));
+  gtk_widget_set_tooltip_text (palette_button, _("Adds the currently selected command in the list of commands to a palette\nYou can create a new, custom palette, and you can change the label of the button you create by right-clicking on it."));
+  gtk_box_pack_end (GTK_BOX (inner_vbox), palette_button, FALSE, TRUE, 0);
+  g_signal_connect_swapped (G_OBJECT (execute_button), "clicked", G_CALLBACK (execute_current), &cbdata);
+  g_signal_connect_swapped (G_OBJECT (palette_button), "clicked", G_CALLBACK (add_current_to_palette), &cbdata);
+
+  
+  
+  
+  
   statusbar = gtk_statusbar_new ();
   context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "");
   //FIXME gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(statusbar), FALSE);
@@ -455,7 +524,10 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
       gtk_tree_view_scroll_to_cell ((GtkTreeView *) command_tree_view, path, NULL, FALSE, 0, 0);
       gtk_tree_path_free (path);
     }
+  gtk_widget_grab_focus (SearchEntry);
   gtk_tree_selection_select_iter (selection, &iter);
+  
+  
   frame = gtk_frame_new (_("Setting the Cursor Shape for Mouse Ops"));
   gtk_frame_set_shadow_type ((GtkFrame *) frame, GTK_SHADOW_IN);
   //gtk_container_add (GTK_CONTAINER (vbox), frame);
@@ -486,6 +558,7 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   g_object_set_data ((GObject *) mouse_state2, "mask", (gpointer) GDK_BUTTON1_MASK);
   gtk_box_pack_start (GTK_BOX (vbox), mouse_state2, FALSE, TRUE, 0);
 
+  {
   GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
   label = gtk_label_new (_("Cursor Shape #"));
@@ -495,6 +568,8 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   GtkWidget *spinner = gtk_spin_button_new ((GtkAdjustment *) spinner_adj, 1.0, 0);
   gtk_box_pack_start (GTK_BOX (inner_hbox), spinner, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (spinner), "value-changed", G_CALLBACK (set_cursor_number), &info.cursor_number);
+  }
+
   //FIXME here use gdk_cursor_get_image() to show the cursor selected.
 
 
@@ -507,26 +582,17 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
 
   g_signal_connect (G_OBJECT (button_save), "clicked", G_CALLBACK (save_default_keymap_file), NULL);
   g_signal_connect (G_OBJECT (button_save_as), "clicked", G_CALLBACK (save_keymap_dialog), NULL);
-  g_signal_connect (G_OBJECT (button_load), "clicked", G_CALLBACK (load_system_keymap_dialog_response), dialog);
-
-
-
-  g_signal_connect (G_OBJECT (button_load_from), "clicked", G_CALLBACK (load_keymap_dialog_response), dialog);
-
-
-
-  gtk_widget_show_all (dialog);
-  gint val = gtk_dialog_run (GTK_DIALOG (dialog));
+  g_signal_connect (G_OBJECT (button_load), "clicked", G_CALLBACK (load_system_keymap_dialog_response), NULL);
+  g_signal_connect (G_OBJECT (button_load_from), "clicked", G_CALLBACK (load_keymap_dialog_response), NULL);
+ 
+  gtk_widget_show_all (Denemo.command_manager);
+  g_signal_connect (Denemo.command_manager, "delete-event", G_CALLBACK (keymap_cleanup_command_view), &cbdata);
+//!!!!  gtk_main(); not needed now??? but Denemo.command_manager needs setting to NULL if we actually allow destroy.
 
   //When closing the dialog remove the signals that were associated to the
   //dialog
-  keymap_cleanup_command_view (&cbdata);
-  gtk_widget_destroy (dialog);
-  if (val == RESPONSE_LOADED)
-    {
-      // test for if load has been performed i.e. finished, if so
-      // configure_keyboard_dialog_init_idx (action, command_idx);
-    }
+ //FIXME is this needed??? keymap_cleanup_command_view (&cbdata);
+ 
 }
 
 void
