@@ -4,10 +4,6 @@
 #include <stdio.h>
 #include <string.h>
 
-/* merge types for command sets */
-#define DENEMO_MERGING (1<<0)
-#define DENEMO_INTERACTIVE (1<<1)
-
 /*
  * translate a keybinding from the format used in denemo keymaprc file to the
  * format understood by gtk_accelerator_parse. The output is an allocated string
@@ -219,18 +215,13 @@ add_ui (gchar * menupath, gchar * after, gchar * name)
 }
 
 void
-create_command(gboolean is_script,
-               gchar* scheme,
-               gchar* after,
-               gchar* menupath,
+create_command(gchar* after,
                gchar* fallback,
-               GList* menupaths,
-               gint merge,
                command_row *command)
 {
-  if (is_script)
+  gchar* menupath = NULL;
+  if (command->script_type == COMMAND_SCHEME)
   {
-    scheme = scheme ? scheme : "";
     gboolean new_command = FALSE;
     command->action = lookup_action_from_name (command->name);
     if (command->action == NULL)
@@ -246,55 +237,42 @@ create_command(gboolean is_script,
         g_object_set_data (G_OBJECT (command->action), "after", (gpointer) after);
       register_command_row (Denemo.map, command);
       GtkActionGroup *action_group;
-      //GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
+      // GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
       action_group = Denemo.action_group;
       gtk_action_group_add_action (action_group, command->action);
-      /* create a scheme function to call this script */
+      // create a scheme function to call this script
       create_scheme_function_for_script (command->name);
     }
-    if (menupath)
+
+    if(g_list_length(command->locations) > 0)
     {
-      GList *g;
-      for (g = menupaths; g; g = g->next)
+      GList *g = NULL;
+      for (g = command->locations; g; g = g->next)
       {
         menupath = (gchar *) g->data;
         menupath = menupath ? menupath : (gchar *) "/MainMenu/Other";
         add_ui (menupath, after, command->name);
+      }
+    }
+    else if (fallback)
+    {           
+      /* no path given, use fallback */
+      menupath = fallback;
+      add_ui (menupath, after, command->name);
+    }
 
-      }
-    }
-    else
-    {
-      if (fallback)
-      {           /* no path given, use fallback */
-        menupath = fallback;
-        add_ui (menupath, after, command->name);
-      }
-    }
-    if ((merge & DENEMO_INTERACTIVE) && (merge & DENEMO_MERGING) && new_command)
-    {
-      gchar *msg = g_strdup_printf ("Installed a command in the menu system\nat %s\n", menupath);
-      infodialog (msg);
-      g_free (msg);
-    }
-    /*FIXME free?     gchar *old_scheme = (gchar *)g_object_get_data(G_OBJECT(action), "scheme"); */
-    //g_print("Setting scheme %s\n", scheme);
-    g_object_set_data (G_OBJECT (command->action), "scheme", scheme);
     g_object_set_data (G_OBJECT (command->action), "menupath", menupath);
-    if (new_command)
-    {
-      g_signal_connect (G_OBJECT (command->action), "activate", G_CALLBACK (activate_script), NULL);
-      //g_print("Signal activate is set on action %p %s scheme is %s\n", action, name, scheme);
-    }
 
-    //g_print("scheme now %s", scheme);
+    if (new_command)
+      g_signal_connect (G_OBJECT (command->action), "activate", G_CALLBACK (activate_script), NULL);
+
     // Note the script should *not* be in Default.cmdset
     // to delay loading it, but we should set the signal initally and we should not repeat setting the signal later.
     // the signal does not specify which script will be run, that is decided lazily, when the action is invoked for the first time
 
     if (command->hidden)
       g_object_set_data (G_OBJECT (command->action), "deleted", (gpointer) TRUE);      //Mark hidden items as deleted on loading them
-  }                   // is_script
+  }
   
   // we are not as yet re-writing tooltips etc on builtin commands
   else if (command->hidden)
