@@ -31,6 +31,8 @@
 #define NOTE_ON                 0x90
 #define NOTE_OFF                0x80
 
+#define SHAVING (0.01)          //seconds to shave off a note start time to ensure stopping before noteon is sent, and starting with noteon first note may depend of speed of machine??? FIXME
+
 
 static volatile gboolean playing = FALSE;
 
@@ -76,7 +78,7 @@ update_position (smf_event_t * event)
 
   if (event)
     {
-      if ((event->midi_buffer[0] & 0xf0) == MIDI_NOTE_ON && event->time_seconds - last_draw_time > Denemo.prefs.display_refresh)
+      if (((event->midi_buffer[0] & 0xf0) == MIDI_NOTE_ON) && ((event->time_seconds - last_draw_time) > Denemo.prefs.display_refresh))
         {
           last_draw_time = event->time_seconds;
           queue_redraw_playhead (event);
@@ -119,8 +121,8 @@ start_playing (gchar * callback)
 
   set_start_and_end_objects_for_draw ();
   smf_rewind (smf);
-
-  if(smf_seek_to_seconds (smf, Denemo.gui->si->start_time))
+  gdouble start = (Denemo.gui->si->start_time/get_playback_speed()) - SHAVING;
+  if(smf_seek_to_seconds (smf, (start>0.0)?start:0.0))
     g_debug("smf_seek_to_seconds failed");
 
   initialize_until_time ();
@@ -128,7 +130,7 @@ start_playing (gchar * callback)
   initialize_playhead ();
 
   playing = TRUE;
-  last_draw_time = 0.0;
+  last_draw_time = -1.0;//needed to trigger drawing first note
 }
 
 static gboolean
@@ -321,7 +323,7 @@ get_midi_on_time (GList * events)
 }
 
 
-
+//finds the first note which comes ON after the passed time
 DenemoObject *
 get_obj_for_start_time (smf_t * smf, gdouble time)
 {
@@ -339,12 +341,13 @@ get_obj_for_start_time (smf_t * smf, gdouble time)
     }
   while (event && (((event->midi_buffer[0] & 0xF0) == MIDI_NOTE_OFF) || !event->user_pointer));
   if (initial && smf_seek_to_event (smf, initial))
-      g_debug("smf_seek_to_event failed");
+      g_debug("smf_seek_to_event failed");  //if (event) g_print("sought for endObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
   return NULL;
 }
 
+//finds the first note which comes OFF after the passed time
 DenemoObject *
 get_obj_for_end_time (smf_t * smf, gdouble time)
 {
@@ -362,7 +365,7 @@ get_obj_for_end_time (smf_t * smf, gdouble time)
     }
   while (event && (((event->midi_buffer[0] & 0xF0) == MIDI_NOTE_ON) || !event->user_pointer));
   if (initial && smf_seek_to_event (smf, initial))
-      g_debug("smf_seek_to_event failed");
+      g_debug("smf_seek_to_event failed");//if (event) g_print("sought for startObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
   return NULL;
@@ -756,7 +759,6 @@ process_midi_event (gchar * buf)
     }
 }
 
-#define SHAVING (0.01)          //seconds to shave off a note start time to ensure stopping before noteon is sent, may depend of speed of machine??? FIXME
 
 void
 initialize_until_time (void)
