@@ -20,7 +20,7 @@
 #include "audiointerface.h"
 
 static gboolean lh_down;
-
+static gdouble last_event_x;
 /**
  * Get the mid_c_offset of an object or click from its height relative
  * to the top of the staff.  
@@ -364,6 +364,8 @@ perform_command (gint modnum, mouse_gesture press, gboolean left)
 
 static gboolean selecting = FALSE;
 static gboolean dragging_separator = FALSE;
+static gboolean dragging_audio = FALSE;
+static gboolean dragging_tempo = FALSE;
 
 
 static gboolean
@@ -439,10 +441,30 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
     return FALSE;
   gint allocated_height = get_widget_height (Denemo.scorearea);
   gint line_height = allocated_height * gui->si->system_height;
+  
   if (event->y < 0)
     event->y = 0.0;
   gint line_num = ((int) event->y) / line_height;
 
+  if(gui->si->audio && dragging_audio)
+	{		
+		gui->si->audio->leadin -= 500*(event->x_root - last_event_x)/gui->si->zoom;//g_print("%d %d => %d\n", (int)(10*last_event_x), (int)(10*event->x_root), (int)(10*last_event_x) - (int)(10*event->x_root));
+		last_event_x = event->x_root;
+		update_leadin_widget ( gui->si->audio->leadin/(double)gui->si->audio->samplerate);
+		gtk_widget_queue_draw(Denemo.scorearea);
+		return TRUE; 
+	}
+  if(gui->si->audio && dragging_tempo)
+	{		
+		gdouble change = (event->x_root - last_event_x)/gui->si->zoom;
+		last_event_x = event->x_root;
+		struct placement_info pi;
+		get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+		change /= pi.measure_number;
+		update_tempo_widget ( change);
+		gtk_widget_queue_draw(Denemo.scorearea);
+		return TRUE; 
+	}
 #define DENEMO_MINIMUM_SYSTEM_HEIGHT (0.01)
 
 
@@ -524,10 +546,12 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
   DenemoGUI *gui = Denemo.gui;
   if (gui == NULL || gui->si == NULL)
     return FALSE;
+  gboolean left = (event->button != 3);
   //if the cursor is at a system separator start dragging it
   gint allocated_height = get_widget_height (Denemo.scorearea);
   gint line_height = allocated_height * gui->si->system_height;
   gint line_num = ((int) event->y) / line_height;
+  last_event_x = event->x_root;
   //g_print("diff %d\n", line_height - ((int)event->y)%line_height);
   if (dragging_separator == FALSE)
     if (line_height - ((int) event->y - 8) % line_height < 12)
@@ -539,11 +563,44 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
         return TRUE;
       }
   dragging_separator = FALSE;
+  
+  if(gui->si->audio)
+	{
+	 // g_print("audio %f %f\n", event->x, event->y);
+
+
+	  if(event->y < 20*gui->si->zoom /* see draw.c for this value, the note onsets are drawn in the top 20 pixels */)
+		{
+			if (event->type==GDK_2BUTTON_PRESS) 
+				{	
+					gui->si->marked_onset_position = (gint)event->x/gui->si->zoom;
+					if(gui->si->marked_onset_position < KEY_MARGIN + SPACE_FOR_TIME + gui->si->maxkeywidth) {
+						 MouseGestureShow(_("Double Click Note Onset"), _("This represents detected note onsets which occur\nbefore the start of the score.\nIf they are just noise,\nor if you are working on just a portion of the audio that is ok.\nOtherwise drag with left mouse button to synchronize\nwith the start of the score."),
+          MouseGesture);
+						
+					}
+					gtk_widget_queue_draw(Denemo.scorearea);
+					return TRUE;
+				} else 
+				{
+					gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (left?GDK_SB_H_DOUBLE_ARROW:GDK_X_CURSOR));
+					left? (dragging_audio = TRUE) : (dragging_tempo = TRUE);
+					 left? MouseGestureShow(_("Left Drag Note Onset"), _("This moves the audio to synchronize the start with the score.\nYou can use the Leadin button for this too."),
+          MouseGesture) :
+						MouseGestureShow(_("Right Drag Note Onset"), _("This changes the tempo of the score.\nUse this to synchronize the beat after setting the start"),
+          MouseGesture);
+					return TRUE;
+				}
+		}
+	  
+	}
+  
+  
   //g_print("before %f %f\n", event->x, event->y);
   transform_coords (&event->x, &event->y);
   //g_print("after %f %f\n", event->x, event->y);
 
-  gboolean left = (event->button != 3);
+  
   gtk_widget_grab_focus (widget);
   gint key = gui->si->maxkeywidth;
   gint cmajor = key ? 0 : 5;    //allow some area for keysig in C-major
@@ -744,7 +801,12 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
   if (gui == NULL || gui->si == NULL)
     return FALSE;
   gboolean left = (event->button != 3);
-
+  if(gui->si->audio && (dragging_tempo || dragging_audio))
+	{		
+			dragging_tempo = dragging_audio = FALSE;
+			gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
+			return TRUE; 
+	}
   if (dragging_separator)
     {
       if (Denemo.prefs.learning)
