@@ -67,7 +67,6 @@ struct callbackdata
   GtkWidget *saveparts;
   GtkWidget *autosave;
   GtkWidget *toolbar;
-  GtkWidget *notation_palette;
   GtkWidget *rhythm_palette;
   GtkWidget *object_palette;
   GtkWidget *midi_in_controls;
@@ -278,7 +277,7 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNBOOLEAN (return_key_is_special)
     ASSIGNBOOLEAN (newbie)
     ASSIGNBOOLEAN (learning)
-    ASSIGNBOOLEAN (startmidiin) ASSIGNBOOLEAN (applytoselection) ASSIGNBOOLEAN (quickshortcuts) ASSIGNBOOLEAN (autosave) ASSIGNINT (autosave_timeout) ASSIGNBOOLEAN (midi_in_controls) ASSIGNBOOLEAN (playback_controls) ASSIGNBOOLEAN (console_pane) ASSIGNBOOLEAN (lyrics_pane) ASSIGNBOOLEAN (visible_directive_buttons) ASSIGNBOOLEAN (autoupdate) ASSIGNBOOLEAN (toolbar) ASSIGNBOOLEAN (notation_palette) ASSIGNBOOLEAN (rhythm_palette) ASSIGNBOOLEAN (object_palette) ASSIGNBOOLEAN (saveparts)
+    ASSIGNBOOLEAN (startmidiin) ASSIGNBOOLEAN (applytoselection) ASSIGNBOOLEAN (quickshortcuts) ASSIGNBOOLEAN (autosave) ASSIGNINT (autosave_timeout) ASSIGNBOOLEAN (midi_in_controls) ASSIGNBOOLEAN (playback_controls) ASSIGNBOOLEAN (console_pane) ASSIGNBOOLEAN (lyrics_pane) ASSIGNBOOLEAN (visible_directive_buttons) ASSIGNBOOLEAN (autoupdate) ASSIGNBOOLEAN (toolbar) ASSIGNBOOLEAN (rhythm_palette) ASSIGNBOOLEAN (object_palette) ASSIGNBOOLEAN (saveparts)
     //g_print ("Timeout %d \n", prefs->autosave_timeout);
     if (midi_in_device_was_default && strcmp (prefs->portmidi_input_device->str, "default"))
     {
@@ -503,7 +502,6 @@ preferences_change (GtkAction * action, gpointer param)
   BOOLEANENTRY (_("Highlight the cursor"), cursor_highlight);
 
   BOOLEANENTRY (_("Display general toolbar"), toolbar);
-  BOOLEANENTRY (_("Display Note/Rest entry toolbar"), notation_palette);
 
   BOOLEANENTRY (_("Display Controls for Incoming MIDI signals"), midi_in_controls);
   BOOLEANENTRY (_("Display Controls for Playback"), playback_controls);
