@@ -59,6 +59,80 @@ point_to_new_movement (DenemoGUI * gui)
   gui->si->undo_guard = Denemo.prefs.disable_undo;
 }
 
+static void select_movement (gint movementnum) {
+	goto_movement_staff_obj (NULL, movementnum, 0, 0, 0);
+	set_movement_selector (Denemo.gui);
+	displayhelper (Denemo.gui);
+	write_status (Denemo.gui);	
+}
+
+#define NUM_MOVEMENTS_TO_SHOW (2*5)
+void set_movement_selector (DenemoGUI *gui)
+{
+  GtkWidget *button;
+  GList *g;
+  gint i;
+  
+  if(gui->movements_selector)
+	gtk_widget_destroy (gui->movements_selector);
+  gui->movements_selector = (GtkWidget*)gtk_hbox_new(FALSE,1);
+  gtk_box_pack_start(GTK_BOX(gui->buttonbox), gui->movements_selector,  FALSE, TRUE, 0);
+  gtk_widget_show (gui->movements_selector);
+  gint num_movements = 1;
+  gint last = 1, first = 1;
+  if(gui->movements) {
+	  gint current = g_list_index (gui->movements, gui->si) + 1;
+	  num_movements = g_list_length(gui->movements);
+	  first = current - NUM_MOVEMENTS_TO_SHOW/2;
+	  if(first<1) first = 1;
+	  last = first + NUM_MOVEMENTS_TO_SHOW -1;
+	  
+	  if(last>num_movements) 
+	  {
+		  last = num_movements;
+		  first = num_movements - NUM_MOVEMENTS_TO_SHOW;
+		  if(first<1) first = 1;
+		}
+  }
+  for (g=gui->movements, i=1;g;g=g->next, i++)
+	{
+		if(i<first)
+			continue;
+		if(i>last)
+			continue;
+		button = gtk_button_new_with_label("");
+		if (g->data == gui->si)
+		{
+			gchar *text = g_strdup_printf("<span foreground=\"blue\"><i><b>%d</b></i></span>", i);
+			GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));
+			gtk_label_set_use_markup (GTK_LABEL(label_widget), TRUE);
+			gtk_label_set_markup (GTK_LABEL (label_widget), text);
+			g_free(text);
+			text = g_strdup_printf(_("This is the current movement number %d\nClick on another button to change movements"), i);
+			gtk_widget_set_tooltip_text (button, text);
+			g_free(text);
+		} else 
+		{
+			gchar *more = "";
+			if((last<num_movements) && (i==last))
+				more = "+...";
+			gchar *text = g_strdup_printf("%d%s", i, more);
+			gtk_button_set_label (button, text);
+			g_free(text);
+			text = g_strdup_printf(_("Click to switch to movement number %d"), i);
+			gtk_widget_set_tooltip_text (button, text);
+			g_free(text);
+		}
+		
+		
+		gtk_widget_set_can_focus (button, FALSE);
+		gtk_widget_show(button);
+		g_signal_connect_swapped (G_OBJECT(button), "clicked", G_CALLBACK (select_movement), (gpointer) i);
+		gtk_box_pack_start (GTK_BOX(gui->movements_selector), button,  FALSE, TRUE, 0);
+	}
+	if(i==2) 
+		gtk_widget_hide (gui->movements_selector);
+}
 static void
 new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
 {
@@ -70,6 +144,9 @@ new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
   gui->movements = g_list_insert (gui->movements, newsi, before ? pos : pos + 1);
   newsi->currentmovementnum = 1 + g_list_index (gui->movements, newsi);
   setcurrentprimarystaff (gui->si);
+  gui->movements_selector = NULL;
+  set_movement_selector (gui);
+  
   rewind_audio ();
   write_status (gui);
 }
@@ -98,6 +175,7 @@ append_movement (GtkAction * action, gpointer param, gboolean populate)
     }
   gui->movements = g_list_append (gui->movements, gui->si);
   gui->si->currentmovementnum = 1 + g_list_index (gui->movements, gui->si);
+  set_movement_selector (gui);
   gui->si->undo_guard = Denemo.prefs.disable_undo;
   call_out_to_guile ("(d-DirectivePut-header-postfix \"SuppressTitleRepeats\" \"title = ##f\ninstrument = ##f\n\")");
   set_width_to_work_with (gui);
@@ -204,7 +282,7 @@ delete_movement (GtkAction * action, gpointer param)
   reset_movement_numbers (gui);
   g_string_free (primary, TRUE);
   g_string_free (secondary, TRUE);
-
+  set_movement_selector (gui);
   set_movement_transition (-MOVEMENT_WIDTH);
   displayhelper (gui);
   score_status (gui, TRUE);
@@ -267,6 +345,7 @@ goto_movement_staff_obj (DenemoGUI * possible_gui, gint movementnum, gint staffn
         return FALSE;
       gui->si->cursor_appending = TRUE;
     }
+  set_movement_selector (gui);
   write_status (gui);
   move_viewport_up (gui);
   move_viewport_down (gui);
@@ -354,6 +433,7 @@ next_movement (GtkAction * action, DenemoScriptParam * param)
     gtk_widget_show (gui->si->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
   gtk_widget_show (gui->si->buttonbox);
   set_master_tempo (gui->si, 1.0);
+  set_movement_selector (gui);
   //!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
   set_rightmeasurenum (gui->si);
@@ -402,6 +482,7 @@ prev_movement (GtkAction * action, DenemoScriptParam * param)
     gtk_widget_show (gui->si->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
   gtk_widget_show (gui->si->buttonbox);
   set_master_tempo (gui->si, 1.0);
+   set_movement_selector (gui);
   //!!!!!!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
   set_rightmeasurenum (gui->si);
@@ -428,7 +509,7 @@ prev_movement (GtkAction * action, DenemoScriptParam * param)
 void
 init_score (DenemoScore * si, DenemoGUI * gui)
 {
-  gchar *dir = (gchar *) get_user_data_dir ();
+  gchar *dir = (gchar *) get_user_data_dir (TRUE);
 
   si->readonly = 0;
   si->leftmeasurenum = si->rightmeasurenum = 1;
@@ -498,6 +579,7 @@ init_score (DenemoScore * si, DenemoGUI * gui)
   si->undo_guard = 1;           //do not collect undo information until file is loaded
 
   si->buttonbox = gtk_hbox_new (FALSE, 1);
+  set_movement_selector (gui);
   gtk_widget_set_tooltip_text (si->buttonbox, _("A button bar that can be populated by Movement titles and other user generated buttons.\nGenerally by clicking the button you can edit the title or value or execute the action of the button"));
   gtk_box_pack_end (GTK_BOX (gui->buttonboxes), si->buttonbox, FALSE, TRUE, 0);
   gtk_widget_show (si->buttonbox);
