@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <gdk/gdk.h>
 #if GTK_MAJOR_VERSION==3
-#if 1 //remove this and the corresponding endif to compile and test on gkt3
+#if 1                           //remove this and the corresponding endif to compile and test on gkt3
 
 #ifdef G_OS_WIN32
 #include "windows.h"
@@ -34,21 +34,21 @@
 #include <gdk/gdkx.h>
 #endif
 
-typedef void (* SelectAreaCallback) (GdkRectangle *rectangle);
+typedef void (*SelectAreaCallback) (GdkRectangle * rectangle);
+
+typedef struct
+{
+  GdkRectangle rect;
+  GdkRectangle draw_rect;
+  gboolean button_pressed;
 
-typedef struct {
-  GdkRectangle  rect;
-  GdkRectangle  draw_rect;
-  gboolean      button_pressed;
-  
   GtkWidget *window;
   gboolean aborted;
 } select_area_filter_data;
 
-static
-select_area_filter_data the_data;
+static select_area_filter_data the_data;
 static gboolean
-select_window_draw (GtkWidget *window, cairo_t *cr, gpointer unused)
+select_window_draw (GtkWidget * window, cairo_t * cr, G_GNUC_UNUSED gpointer unused)
 {
   GtkAllocation allocation;
   GtkStyle *style;
@@ -69,9 +69,7 @@ select_window_draw (GtkWidget *window, cairo_t *cr, gpointer unused)
       gdk_cairo_set_source_color (cr, &style->base[GTK_STATE_SELECTED]);
       cairo_paint_with_alpha (cr, 0.25);
 
-      cairo_rectangle (cr,
-                       allocation.x + 0.5, allocation.y + 0.5,
-                       allocation.width - 1, allocation.height - 1);
+      cairo_rectangle (cr, allocation.x + 0.5, allocation.y + 0.5, allocation.width - 1, allocation.height - 1);
       cairo_stroke (cr);
     }
   else
@@ -82,6 +80,7 @@ select_window_draw (GtkWidget *window, cairo_t *cr, gpointer unused)
 
   return TRUE;
 }
+
 static GtkWidget *
 create_select_window (void)
 {
@@ -110,18 +109,20 @@ create_select_window (void)
 
 
 static void
-rectangle_found_cb (GdkRectangle *rectangle)
+rectangle_found_cb (GdkRectangle * rectangle)
 {
-  if (rectangle != NULL) {
+  if (rectangle != NULL)
+    {
 
-    the_data.rect = *rectangle;//structure copy
-  }
- else
-  the_data.rect.width = -1;
- gtk_main_quit ();
+      the_data.rect = *rectangle;       //structure copy
+    }
+  else
+    the_data.rect.width = -1;
+  gtk_main_quit ();
 }
 
-typedef struct {
+typedef struct
+{
   GdkRectangle rectangle;
   SelectAreaCallback callback;
   gboolean aborted;
@@ -144,24 +145,21 @@ emit_select_callback_in_idle (gpointer user_data)
 
 
 static void
-empty_rectangle (gint x_root, gint y_root,
-                          GdkRectangle *rect,
-                          GdkRectangle *draw_rect)
+empty_rectangle (gint x_root, gint y_root, GdkRectangle * rect, GdkRectangle * draw_rect)
 {
   rect->x = x_root;
   rect->y = y_root;
 
   draw_rect->x = rect->x;
   draw_rect->y = rect->y;
-  draw_rect->width  = 0;
+  draw_rect->width = 0;
   draw_rect->height = 0;
 }
 
 static void
-fix_rectangle (gint x_root, gint y_root,
-                            GdkRectangle *rect)
+fix_rectangle (gint x_root, gint y_root, GdkRectangle * rect)
 {
-  rect->width  = ABS (rect->x - x_root);
+  rect->width = ABS (rect->x - x_root);
   rect->height = ABS (rect->y - y_root);
 
   rect->x = MIN (rect->x, x_root);
@@ -169,10 +167,7 @@ fix_rectangle (gint x_root, gint y_root,
 }
 
 static void
-select_area_motion_action (GtkWidget *window,
-                           GdkRectangle *rect,
-                           GdkRectangle *pdraw_rect,
-                           gint x_root, gint y_root)
+select_area_motion_action (GtkWidget * window, GdkRectangle * rect, GdkRectangle * pdraw_rect, gint x_root, gint y_root)
 {
   GdkRectangle draw_rect = (*pdraw_rect);
 
@@ -208,85 +203,84 @@ select_area_motion_action (GtkWidget *window,
         gdk_window_shape_combine_region (gdkwindow, NULL, 0, 0);
     }
 
-   
-  draw_rect.width  = ABS (rect->x - x_root);
+
+  draw_rect.width = ABS (rect->x - x_root);
   draw_rect.height = ABS (rect->y - y_root);
 
   draw_rect.x = MIN (rect->x, x_root);
   draw_rect.y = MIN (rect->y, y_root);
-  
-  g_print("... and Drew %d %d for %d, %d\n", draw_rect.x, draw_rect.y,
-                        draw_rect.width, draw_rect.height);
-  
+
+  g_print ("... and Drew %d %d for %d, %d\n", draw_rect.x, draw_rect.y, draw_rect.width, draw_rect.height);
+
 }
 
-
-select_area_button_press (GtkWidget               *window,
-                          GdkEventButton          *event,
-                          select_area_filter_data *data) {
+gboolean
+select_area_button_press (GtkWidget * window, GdkEventButton * event, select_area_filter_data * data)
+{
   gdouble xroot, yroot;
   gint x_root, y_root;
-  gdk_event_get_root_coords (event, &xroot, &yroot);
-  x_root = (gint)xroot;
-  y_root = (gint)yroot;
-  gboolean left = (event->button!=3);
-  if(left) {
-    if (!data->button_pressed) {
-        empty_rectangle (x_root, y_root,
-                                    &data->rect, &data->draw_rect);//sets the origin, width, height 0
-        data->button_pressed = TRUE;
-    } else {
-        fix_rectangle (x_root, y_root,
-                                    &data->rect);//sets the far corner                      
-        gtk_main_quit ();
-      }
-  } else {
-          gint x = x_root;
-          gint y = y_root;
-          GdkDisplay *disp = gdk_display_get_default();
-          g_print("moving pointer to x %d y %d\n", data->rect.x, data->rect.y);
-          gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data->rect.x, data->rect.y);
-          data->rect.x = x;
-          data->rect.y = y;
+  gdk_event_get_root_coords ((GdkEvent*) event, &xroot, &yroot);
+  x_root = (gint) xroot;
+  y_root = (gint) yroot;
+  gboolean left = (event->button != 3);
+  if (left)
+    {
+      if (!data->button_pressed)
+        {
+          empty_rectangle (x_root, y_root, &data->rect, &data->draw_rect);      //sets the origin, width, height 0
+          data->button_pressed = TRUE;
         }
+      else
+        {
+          fix_rectangle (x_root, y_root, &data->rect);  //sets the far corner                      
+          gtk_main_quit ();
+        }
+    }
+  else
+    {
+      gint x = x_root;
+      gint y = y_root;
+      GdkDisplay *disp = gdk_display_get_default ();
+      g_print ("moving pointer to x %d y %d\n", data->rect.x, data->rect.y);
+      gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data->rect.x, data->rect.y);
+      data->rect.x = x;
+      data->rect.y = y;
+    }
   return TRUE;
 }
 
 static gboolean
-select_area_motion_notify (GtkWidget               *window,
-                           GdkEventMotion          *event,
-                           select_area_filter_data *data) {     
+select_area_motion_notify (GtkWidget * window, GdkEventMotion * event, select_area_filter_data * data)
+{
   gdouble xroot, yroot;
   gint x_root, y_root;
-  gdk_event_get_root_coords (event, &xroot, &yroot);
-  x_root = (gint)xroot;
-  y_root = (gint)yroot;
-  select_area_motion_action (window,
-                                   &data->rect, &data->draw_rect,
-                                   x_root, y_root);//draws the rectangle
+  gdk_event_get_root_coords ((GdkEvent*) event, &xroot, &yroot);
+  x_root = (gint) xroot;
+  y_root = (gint) yroot;
+  select_area_motion_action (window, &data->rect, &data->draw_rect, x_root, y_root);    //draws the rectangle
   return TRUE;
 
 }
-static gboolean
-select_area_key_press (GtkWidget               *window,
-                       GdkEventKey             *event,
-                       select_area_filter_data *data){
 
- data->button_pressed = FALSE;    
- data->rect.x = 0;
- data->rect.y = 0;
- data->rect.width  = 0;
- data->rect.height = 0;
- gtk_main_quit ();
- return TRUE;
-        
+static gboolean
+select_area_key_press (GtkWidget * window, GdkEventKey * event, select_area_filter_data * data)
+{
+
+  data->button_pressed = FALSE;
+  data->rect.x = 0;
+  data->rect.y = 0;
+  data->rect.width = 0;
+  data->rect.height = 0;
+  gtk_main_quit ();
+  return TRUE;
+
 }
 
 void
 screenshot_select_area_async (SelectAreaCallback callback)
 {
   GdkCursor *cursor;
-  select_area_filter_data  data;
+  select_area_filter_data data;
   CallbackData *cb_data;
   GdkDeviceManager *manager;
   GdkDevice *pointer, *keyboard;
@@ -294,11 +288,11 @@ screenshot_select_area_async (SelectAreaCallback callback)
 
   data.rect.x = 0;
   data.rect.y = 0;
-  data.rect.width  = 0;
+  data.rect.width = 0;
   data.rect.height = 0;
   data.button_pressed = FALSE;
   data.aborted = FALSE;
-  data.window = create_select_window();
+  data.window = create_select_window ();
 
   cb_data = g_slice_new0 (CallbackData);
   cb_data->callback = callback;
@@ -312,12 +306,7 @@ screenshot_select_area_async (SelectAreaCallback callback)
   pointer = gdk_device_manager_get_client_pointer (manager);
   keyboard = gdk_device_get_associated_device (pointer);
 
-  res = gdk_device_grab (pointer, gtk_widget_get_window (data.window),
-                         GDK_OWNERSHIP_NONE, FALSE,
-                         GDK_POINTER_MOTION_MASK |
-                         GDK_BUTTON_PRESS_MASK | 
-                         GDK_BUTTON_RELEASE_MASK,
-                         cursor, GDK_CURRENT_TIME);
+  res = gdk_device_grab (pointer, gtk_widget_get_window (data.window), GDK_OWNERSHIP_NONE, FALSE, GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK, cursor, GDK_CURRENT_TIME);
 
   if (res != GDK_GRAB_SUCCESS)
     {
@@ -325,11 +314,7 @@ screenshot_select_area_async (SelectAreaCallback callback)
       goto out;
     }
 
-  res = gdk_device_grab (keyboard, gtk_widget_get_window (data.window),
-                         GDK_OWNERSHIP_NONE, FALSE,
-                         GDK_KEY_PRESS_MASK |
-                         GDK_KEY_RELEASE_MASK,
-                         NULL, GDK_CURRENT_TIME);
+  res = gdk_device_grab (keyboard, gtk_widget_get_window (data.window), GDK_OWNERSHIP_NONE, FALSE, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK, NULL, GDK_CURRENT_TIME);
   if (res != GDK_GRAB_SUCCESS)
     {
       gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
@@ -347,7 +332,7 @@ screenshot_select_area_async (SelectAreaCallback callback)
 
   gdk_flush ();
 
- out:
+out:
   cb_data->aborted = data.aborted;
   cb_data->rectangle = data.rect;
 
@@ -360,20 +345,22 @@ screenshot_select_area_async (SelectAreaCallback callback)
 
 
 gboolean
-screenshot_select_area (int *px, int *py, int *pwidth, int *pheight){
-  screenshot_select_area_async(rectangle_found_cb);
+screenshot_select_area (int *px, int *py, int *pwidth, int *pheight)
+{
+  screenshot_select_area_async (rectangle_found_cb);
   gtk_main ();
-if(the_data.rect.width>0) {
-  *px = the_data.rect.x;
-  *py = the_data.rect.y;
-  *pwidth  = the_data.rect.width;
-  *pheight = the_data.rect.height;
-  the_data.rect.x += the_data.rect.width;
-  the_data.rect.y += the_data.rect.height;
-  return TRUE;
-}
-else
-return FALSE;
+  if (the_data.rect.width > 0)
+    {
+      *px = the_data.rect.x;
+      *py = the_data.rect.y;
+      *pwidth = the_data.rect.width;
+      *pheight = the_data.rect.height;
+      the_data.rect.x += the_data.rect.width;
+      the_data.rect.y += the_data.rect.height;
+      return TRUE;
+    }
+  else
+    return FALSE;
 }
 
 GdkRectangle *
@@ -381,43 +368,41 @@ screenshot_find_rectangle (void)
 {
   GdkRectangle *rectangle;
   rectangle = g_new0 (GdkRectangle, 1);
-  if (screenshot_select_area (&rectangle->x, &rectangle->y,
-                              &rectangle->width, &rectangle->height)) {
-    if ((rectangle->width > 0) && (rectangle->height > 0))
-      return rectangle;
-  }
+  if (screenshot_select_area (&rectangle->x, &rectangle->y, &rectangle->width, &rectangle->height))
+    {
+      if ((rectangle->width > 0) && (rectangle->height > 0))
+        return rectangle;
+    }
   g_free (rectangle);
   return NULL;
 }
 
 GdkPixbuf *
-screenshot_get_pixbuf (GdkWindow    *window,
-                       GdkRectangle *rectangle)
+screenshot_get_pixbuf (GdkWindow * window, GdkRectangle * rectangle)
 {
   GdkWindow *root;
   GdkPixbuf *screenshot = NULL;
-  gint  x_orig, y_orig;
-  gint width, real_width, height, real_height;
+  gint x_orig, y_orig;
+  gint width, height;
   root = gdk_get_default_root_window ();
 
   if (rectangle)
     {
       x_orig = rectangle->x;
       y_orig = rectangle->y;
-      width  = rectangle->width;
+      width = rectangle->width;
       height = rectangle->height;
-      if(width>0 && height>0)
-        screenshot = gdk_pixbuf_get_from_window	(root, x_orig, y_orig, width, height);
-   }
+      if (width > 0 && height > 0)
+        screenshot = gdk_pixbuf_get_from_window (root, x_orig, y_orig, width, height);
+    }
   return screenshot;
 }
 #else
 GdkPixbuf *
-screenshot_get_pixbuf (GdkWindow    *window,
-                       GdkRectangle *rectangle)
+screenshot_get_pixbuf (GdkWindow * window, GdkRectangle * rectangle)
 {
-g_warning("Not available on gtk3 yet\n");
-return NULL;
+  g_warning ("Not available on gtk3 yet\n");
+  return NULL;
 }
 #endif //remove to compile and test on gtk3
 
@@ -457,41 +442,36 @@ return NULL;
 
 
 
-typedef struct {
-  GdkRectangle  rect;
-  GdkRectangle  draw_rect;
-  gboolean      button_pressed;
+typedef struct
+{
+  GdkRectangle rect;
+  GdkRectangle draw_rect;
+  gboolean button_pressed;
   /* only needed because we're not using cairo to draw the rectangle */
-  GdkWindow    *root;
-  GdkGC        *gc;
+  GdkWindow *root;
+  GdkGC *gc;
 } select_area_filter_data;
 
 
 #ifdef G_OS_WIN32
 #else
 static void
-empty_rectangle (XButtonEvent    *event,
-                          GdkRectangle *rect,
-                          GdkRectangle *draw_rect)
+empty_rectangle (XButtonEvent * event, GdkRectangle * rect, GdkRectangle * draw_rect)
 {
   rect->x = event->x_root;
   rect->y = event->y_root;
 
   draw_rect->x = rect->x;
   draw_rect->y = rect->y;
-  draw_rect->width  = 0;
+  draw_rect->width = 0;
   draw_rect->height = 0;
 }
 
 static void
-fix_rectangle (XButtonEvent    *event,
-                            GdkRectangle *rect,
-                            GdkRectangle *draw_rect,
-                            GdkWindow    *root,
-                            GdkGC        *gc)
+fix_rectangle (XButtonEvent * event, GdkRectangle * rect, GdkRectangle * draw_rect, GdkWindow * root, GdkGC * gc)
 {
   /* do not remove the old rectangle as it shows you what you have captured so far */
-  rect->width  = ABS (rect->x - event->x_root);
+  rect->width = ABS (rect->x - event->x_root);
   rect->height = ABS (rect->y - event->y_root);
 
   rect->x = MIN (rect->x, event->x_root);
@@ -499,20 +479,14 @@ fix_rectangle (XButtonEvent    *event,
 }
 
 static void
-select_area_motion_notify (XButtonEvent    *event,
-                           GdkRectangle *rect,
-                           GdkRectangle *draw_rect,
-                           GdkWindow    *root,
-                           GdkGC        *gc)
+select_area_motion_notify (XButtonEvent * event, GdkRectangle * rect, GdkRectangle * draw_rect, GdkWindow * root, GdkGC * gc)
 {
   /* FIXME: draw some nice rubberband with cairo if composited */
 
   /* remove the old rectangle */
   if (draw_rect->width > 0 && draw_rect->height > 0)
-    gdk_draw_rectangle (root, gc, FALSE, 
-                        draw_rect->x, draw_rect->y,
-                        draw_rect->width, draw_rect->height);
-  draw_rect->width  = ABS (rect->x - event->x_root);
+    gdk_draw_rectangle (root, gc, FALSE, draw_rect->x, draw_rect->y, draw_rect->width, draw_rect->height);
+  draw_rect->width = ABS (rect->x - event->x_root);
   draw_rect->height = ABS (rect->y - event->y_root);
 
   draw_rect->x = MIN (rect->x, event->x_root);
@@ -520,112 +494,105 @@ select_area_motion_notify (XButtonEvent    *event,
 
   /* draw the new rectangle */
   if (draw_rect->width > 0 && draw_rect->height > 0)
-    gdk_draw_rectangle (root, gc, FALSE, 
-                        draw_rect->x, draw_rect->y,
-                        draw_rect->width, draw_rect->height);
+    gdk_draw_rectangle (root, gc, FALSE, draw_rect->x, draw_rect->y, draw_rect->width, draw_rect->height);
 }
 #endif
 
 
 static GdkFilterReturn
-select_area_filter (GdkXEvent *gdk_xevent,
-                    GdkEvent  *event,
-                    gpointer   user_data)
+select_area_filter (GdkXEvent * gdk_xevent, GdkEvent * event, gpointer user_data)
 {
   select_area_filter_data *data = user_data;
 #ifdef G_OS_WIN32
-  MSG *wevent = (MSG*) gdk_xevent;
-g_print("Received event %x %x %x at %ld %ld\n", wevent->message, wevent->wParam, wevent->lParam, wevent->pt.x, wevent->pt.y);
-return GDK_FILTER_REMOVE;
+  MSG *wevent = (MSG *) gdk_xevent;
+  g_print ("Received event %x %x %x at %ld %ld\n", wevent->message, wevent->wParam, wevent->lParam, wevent->pt.x, wevent->pt.y);
+  return GDK_FILTER_REMOVE;
 #else
   XEvent *xevent = (XEvent *) gdk_xevent;
   switch (xevent->type)
     {
     case ButtonPress:
-      switch(xevent->xbutton.button) {
+      switch (xevent->xbutton.button)
+        {
         case 1:
-          if (!data->button_pressed) {
-            empty_rectangle (&xevent->xbutton,
-                                    &data->rect, &data->draw_rect);//sets the origin, width, height 0
-            data->button_pressed = TRUE;
-          } else {
-            fix_rectangle (&xevent->xbutton,
-                                    &data->rect, &data->draw_rect,
-                                    data->root, data->gc);//sets the far corner                      
-            gtk_main_quit ();
-          }
+          if (!data->button_pressed)
+            {
+              empty_rectangle (&xevent->xbutton, &data->rect, &data->draw_rect);        //sets the origin, width, height 0
+              data->button_pressed = TRUE;
+            }
+          else
+            {
+              fix_rectangle (&xevent->xbutton, &data->rect, &data->draw_rect, data->root, data->gc);    //sets the far corner                      
+              gtk_main_quit ();
+            }
           break;
         case 2:
         case 3:
-        case 4: //scroll up
-        case 5: //scroll down
-         {
-          gint x = xevent->xbutton.x_root;
-          gint y = xevent->xbutton.y_root;
-          GdkDisplay *disp = gdk_display_get_default();
-          g_print("moving pointer to x %d y %d\n", data->rect.x, data->rect.y);
-          gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data->rect.x, data->rect.y);
-          data->rect.x = x;
-          data->rect.y = y;
+        case 4:                //scroll up
+        case 5:                //scroll down
+          {
+            gint x = xevent->xbutton.x_root;
+            gint y = xevent->xbutton.y_root;
+            GdkDisplay *disp = gdk_display_get_default ();
+            g_print ("moving pointer to x %d y %d\n", data->rect.x, data->rect.y);
+            gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data->rect.x, data->rect.y);
+            data->rect.x = x;
+            data->rect.y = y;
+            break;
+          }
+        default:
+          g_print ("button %d\n", xevent->xbutton.button);
+          //return GDK_FILTER_CONTINUE; no other application responds to the button press even with this return value.
           break;
         }
-        default:
-        g_print("button %d\n", xevent->xbutton.button);
-        //return GDK_FILTER_CONTINUE; no other application responds to the button press even with this return value.
-        break;
-      }
       return GDK_FILTER_REMOVE;
     case ButtonRelease:
       return GDK_FILTER_REMOVE;
     case MotionNotify:
       if (data->button_pressed)
-        select_area_motion_notify (&xevent->xbutton,
-                                   &data->rect, &data->draw_rect,
-                                   data->root, data->gc);//draws the rectangle
+        select_area_motion_notify (&xevent->xbutton, &data->rect, &data->draw_rect, data->root, data->gc);      //draws the rectangle
       return GDK_FILTER_REMOVE;
     case KeyPress:
-     // if (xevent->xkey.keycode == XKeysymToKeycode (gdk_display, XK_Escape)) let any key end - may need to re-instate this for Ctrl-press to join pixbufs
-        {
-          // this undraws in the wrong place, 
-         // gdk_draw_rectangle (data->root, data->gc, FALSE, 
-         //               data->rect.x - data->rect.width, data->rect.y - data->rect.height,
-          //              data->rect.width, data->rect.height);
-          data->button_pressed = FALSE;    
-          data->rect.x = 0;
-          data->rect.y = 0;
-          data->rect.width  = 0;
-          data->rect.height = 0;
-          gtk_main_quit ();
-          return GDK_FILTER_REMOVE;
-        }
+      // if (xevent->xkey.keycode == XKeysymToKeycode (gdk_display, XK_Escape)) let any key end - may need to re-instate this for Ctrl-press to join pixbufs
+      {
+        // this undraws in the wrong place, 
+        // gdk_draw_rectangle (data->root, data->gc, FALSE, 
+        //               data->rect.x - data->rect.width, data->rect.y - data->rect.height,
+        //              data->rect.width, data->rect.height);
+        data->button_pressed = FALSE;
+        data->rect.x = 0;
+        data->rect.y = 0;
+        data->rect.width = 0;
+        data->rect.height = 0;
+        gtk_main_quit ();
+        return GDK_FILTER_REMOVE;
+      }
       break;
     default:
       break;
     }
- #endif
+#endif
 
 
   return GDK_FILTER_CONTINUE;
 }
 
 gboolean
-screenshot_select_area (int *px, int *py, int *pwidth, int *pheight){
-  GdkWindow               *root;
-  GdkCursor               *cursor;
-  static select_area_filter_data  data;
-  GdkGCValues              values;
-  GdkColor                 color;
+screenshot_select_area (int *px, int *py, int *pwidth, int *pheight)
+{
+  GdkWindow *root;
+  GdkCursor *cursor;
+  static select_area_filter_data data;
+  GdkGCValues values;
+  GdkColor color;
 #ifdef G_OS_WIN32
-g_warning("Not available on windows, sorry");
-return FALSE;
+  g_warning ("Not available on windows, sorry");
+  return FALSE;
 #endif
   root = gdk_get_default_root_window ();
   cursor = gdk_cursor_new (GDK_CROSSHAIR);
 
-  if (gdk_pointer_grab (root, FALSE,
-                        GDK_POINTER_MOTION_MASK|GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK,
-                        NULL, cursor,
-                        GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
+  if (gdk_pointer_grab (root, FALSE, GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK, NULL, cursor, GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
     {
       gdk_cursor_unref (cursor);
       return FALSE;
@@ -656,23 +623,18 @@ return FALSE;
   values.cap_style = GDK_CAP_BUTT;
   values.join_style = GDK_JOIN_MITER;
 
-  data.gc = gdk_gc_new_with_values (root, &values,
-                                    GDK_GC_FUNCTION | GDK_GC_FILL |
-                                    GDK_GC_CLIP_MASK | GDK_GC_SUBWINDOW |
-                                    GDK_GC_CLIP_X_ORIGIN |
-                                    GDK_GC_CLIP_Y_ORIGIN | GDK_GC_EXPOSURES |
-                                    GDK_GC_LINE_WIDTH | GDK_GC_LINE_STYLE |
-                                    GDK_GC_CAP_STYLE | GDK_GC_JOIN_STYLE);
+  data.gc = gdk_gc_new_with_values (root, &values, GDK_GC_FUNCTION | GDK_GC_FILL | GDK_GC_CLIP_MASK | GDK_GC_SUBWINDOW | GDK_GC_CLIP_X_ORIGIN | GDK_GC_CLIP_Y_ORIGIN | GDK_GC_EXPOSURES | GDK_GC_LINE_WIDTH | GDK_GC_LINE_STYLE | GDK_GC_CAP_STYLE | GDK_GC_JOIN_STYLE);
   gdk_color_parse ("white", &color);
   gdk_gc_set_rgb_fg_color (data.gc, &color);
   gdk_color_parse ("black", &color);
   gdk_gc_set_rgb_bg_color (data.gc, &color);
 
-  if(data.button_pressed) {
-    GdkDisplay *disp = gdk_display_get_default();
-    //g_print("re-starting and moving pointer to x %d y %d\n", data.rect.x+data.rect.width, data.rect.y);
-    gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data.rect.x+data.rect.width, data.rect.y-data.rect.height);
-  }
+  if (data.button_pressed)
+    {
+      GdkDisplay *disp = gdk_display_get_default ();
+      //g_print("re-starting and moving pointer to x %d y %d\n", data.rect.x+data.rect.width, data.rect.y);
+      gdk_display_warp_pointer (disp, gdk_display_get_default_screen (disp), data.rect.x + data.rect.width, data.rect.y - data.rect.height);
+    }
 
   gtk_main ();
 
@@ -686,7 +648,7 @@ return FALSE;
 
   *px = data.rect.x;
   *py = data.rect.y;
-  *pwidth  = data.rect.width;
+  *pwidth = data.rect.width;
   *pheight = data.rect.height;
   data.rect.x += data.rect.width;
   data.rect.y += data.rect.height;
@@ -698,22 +660,21 @@ screenshot_find_rectangle (void)
 {
   GdkRectangle *rectangle;
   rectangle = g_new0 (GdkRectangle, 1);
-  if (screenshot_select_area (&rectangle->x, &rectangle->y,
-                              &rectangle->width, &rectangle->height)) {
-    if ((rectangle->width > 0) && (rectangle->height > 0))
-      return rectangle;
-  }
+  if (screenshot_select_area (&rectangle->x, &rectangle->y, &rectangle->width, &rectangle->height))
+    {
+      if ((rectangle->width > 0) && (rectangle->height > 0))
+        return rectangle;
+    }
   g_free (rectangle);
   return NULL;
 }
 
 GdkPixbuf *
-screenshot_get_pixbuf (GdkWindow    *window,
-                       GdkRectangle *rectangle)
+screenshot_get_pixbuf (GdkWindow * window, GdkRectangle * rectangle)
 {
   GdkWindow *root;
   GdkPixbuf *screenshot = NULL;
-  gint  x_orig, y_orig;
+  gint x_orig, y_orig;
   gint width, real_width, height, real_height;
   root = gdk_get_default_root_window ();
 
@@ -721,13 +682,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
     {
       x_orig = rectangle->x;
       y_orig = rectangle->y;
-      width  = rectangle->width;
+      width = rectangle->width;
       height = rectangle->height;
-      if(width>0 && height>0)
-        screenshot = gdk_pixbuf_get_from_drawable (NULL, root, NULL,
-                                              x_orig, y_orig, 0, 0,
-                                              width, height);
-   }
+      if (width > 0 && height > 0)
+        screenshot = gdk_pixbuf_get_from_drawable (NULL, root, NULL, x_orig, y_orig, 0, 0, width, height);
+    }
   return screenshot;
 }
 
