@@ -234,9 +234,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action, DenemoContext con
     g_free (thestaffstruct);
     return;          /* no code for this yet - just edit textually */
   }
-#ifdef DEBUG
-  g_print ("newstaff: Num staffs %d\n", numstaffs);
-#endif
+  g_debug ("newstaff: Num staffs %d\n", numstaffs);
   if (numstaffs == 0)
     {
       action = INITIAL;
@@ -417,13 +415,13 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
 {
   DenemoScore *si = gui->si;
   DenemoStaff *curstaffstruct = si->currentstaff->data;
-
+  gboolean has_next = (si->currentstaff->next != NULL);
   (void) signal_structural_change (gui);
   if (si->currentstaff == NULL)
     return;
 
   gboolean give_info = FALSE;   //give info about removing matching context
-  if (interactive && (curstaffstruct->context != DENEMO_NONE) && (!confirm ("A context is set on this staff", "You will need to alter/delete the matching staff; Proceed?")))
+  if (interactive && (curstaffstruct->context != DENEMO_NONE) && (!confirm (_("A context is set on this staff"), _("You will need to alter/delete the matching staff; Proceed?"))))
     return;
   if (interactive && (curstaffstruct->context != DENEMO_NONE))
     give_info = TRUE;
@@ -465,7 +463,7 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   si->currentstaff = g_list_nth (si->thescore, si->currentstaffnum - 1);
 
 
-  if (isprimary)                // we deleted the primary, so the next one must become the primary
+  if (isprimary && has_next)                // we deleted the primary, so the next one (which is present) must become the primary
     {
       ((DenemoStaff *) si->currentstaff->data)->voicecontrol = DENEMO_PRIMARY;
       si->currentprimarystaff = si->currentstaff;
@@ -485,7 +483,7 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   displayhelper (gui);
   score_status (gui, TRUE);
   if (give_info)
-    infodialog ("The staff deleted had a start/end context; if you still have the staff with the matching end/start context\n then you should remove it (or its context) now.\nSee Staff->properties->context\nYou will not be able to print with miss-matched contexts.");
+    infodialog (_("The staff deleted had a start/end context; if you still have the staff with the matching end/start context\n then you should remove it (or its context) now.\nSee Staff->properties->context\nYou will not be able to print with miss-matched contexts."));
   return;
 }
 
