@@ -35,6 +35,51 @@
 #include <mach-o/dyld.h>
 #endif
 
+/**
+ * This checks to see if there's a .denemo/ directory in the user's
+ * home directory, 
+ * if create tries to create one if there isn't, and returns the
+ * path to it
+ * else returns NULL
+ *
+ * .denemo/ is used for holding configuration files, templates, and so on.
+ *
+ * On windows the home directory is the one containing the My Documents folder.
+ */
+
+const gchar *
+get_user_data_dir (gboolean create)
+{
+  static gchar *dotdenemo = NULL;
+
+  gboolean err;
+  if (!dotdenemo)
+    {
+      dotdenemo = g_build_filename (g_get_home_dir (), ".denemo-" PACKAGE_VERSION, NULL);
+    }
+  if ((!create) && !g_file_test (dotdenemo, G_FILE_TEST_IS_DIR))
+	return NULL;
+  err = g_mkdir_with_parents (dotdenemo, 0770);
+  if (err)
+    {
+      warningdialog (_("Could not create .denemo for you personal settings"));
+      g_free (dotdenemo);
+      dotdenemo = NULL;
+    }
+  return dotdenemo;
+}
+
+/* return a path to a temporary directory to be used for print intermediate files */
+const gchar *
+locateprintdir (void)
+{
+  static gchar *printdir = NULL;
+  if (!printdir)
+    printdir = make_temp_dir ();
+  return printdir;
+}
+
+
 void
 add_font_directory (gchar * fontpath)
 {
@@ -963,18 +1008,19 @@ initdir ()
 }
 
 extern gchar *gbr_find_pkg_data_dir (const gchar * default_pkg_data_dir, const gchar * pkg_name);
-
+  
+static gchar *DENEMO_datadir = NULL;
 const gchar *
 get_system_data_dir ()
 {
-  static gchar *datadir = NULL;
-  if (datadir == NULL)
+  //DENEMO_datadir?g_print("datadir is %s at %p", DENEMO_datadir, DENEMO_datadir):g_print("datadir not yet set");
+  if (DENEMO_datadir == NULL)
     {
 #ifdef G_OS_WIN32
       gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
-      datadir = g_build_filename (rootdir, "share", "denemo", NULL);
+      DENEMO_datadir = g_build_filename (rootdir, "share", "denemo", NULL);
       g_print ("rootdir=%s\n", rootdir);
-      g_print ("datadir=%s\n", datadir);
+      g_print ("datadir=%s\n", DENEMO_datadir);
       g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
@@ -989,20 +1035,20 @@ get_system_data_dir ()
           g_print ("using bin path %s\n", bindir);
         else
           g_critical ("Cannot get bin dir\n");
-        datadir = g_build_filename (g_path_get_dirname (bindir), "..", "share", "denemo", NULL);
-        g_print ("OSX set data dir to %s\n", datadir);
+        DENEMO_datadir = g_build_filename (g_path_get_dirname (bindir), "..", "share", "denemo", NULL);
+        g_print ("OSX set data dir to %s\n", DENEMO_datadir);
       }
 #else
 #ifndef ENABLE_BINRELOC
-      datadir = g_strdup (PKGDATADIR);
+      DENEMO_datadir = g_strdup (PKGDATADIR);
 #else
-      datadir = gbr_find_pkg_data_dir (PKGDATADIR, PKGNAME);
+      DENEMO_datadir = gbr_find_pkg_data_dir (PKGDATADIR, PKGNAME);
 #endif //ENABLE_BINRELOC
 
 #endif //_MACH_O_
 #endif /* not G_OS_WIN32 */
     }
-  return datadir;
+  return DENEMO_datadir;
 }
 
 const gchar *
@@ -1038,18 +1084,18 @@ get_prefix_dir (void)
 #endif //G_OS_WIN32
   return prefix;
 }
-
+static gchar *DENEMO_bindir = NULL;
 const gchar *
 get_system_bin_dir (void)
 {
-  static gchar *bindir = NULL;
-  if (bindir == NULL)
+  
+  if (DENEMO_bindir == NULL)
     {
 #ifdef G_OS_WIN32
       gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
-      bindir = g_build_filename (rootdir, "bin", NULL);
+      DENEMO_bindir = g_build_filename (rootdir, "bin", NULL);
       g_print ("rootdir=%s\n", rootdir);
-      g_print ("bindir=%s\n", bindir);
+      g_print ("bindir=%s\n", DENEMO_bindir);
       g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
@@ -1062,26 +1108,26 @@ get_system_bin_dir (void)
         gchar *bin = (gchar *) g_malloc (size);
         if (_NSGetExecutablePath (bin, &size) == 0)
           {
-            bindir = g_build_filename (bin, "..", NULL);
-            g_print ("using bin path %s\n", bindir);
+            DENEMO_bindir = g_build_filename (bin, "..", NULL);
+            g_print ("using bin path %s\n", DENEMO_bindir);
           }
         else
           g_critical ("Cannot get bin dir\n");
 
-        g_print ("OSX set bin dir to %s\n", bindir);
+        g_print ("OSX set bin dir to %s\n", DENEMO_bindir);
       }
 #else
 
 #ifndef ENABLE_BINRELOC
-      bindir = g_strdup (BINDIR);
+      DENEMO_bindir = g_strdup (BINDIR);
 #else
-      bindir = gbr_find_bin_dir (BINDIR);
+      DENEMO_bindir = gbr_find_bin_dir (BINDIR);
 #endif //ENABLE_BINRELOC
 
 #endif //_MACH_O_
 #endif /* not G_OS_WIN32 */
     }
-  return bindir;
+  return DENEMO_bindir;
 }
 
 /** UNUSED
@@ -1624,13 +1670,16 @@ display_current_object (void)
           break;
         case CLEF:
           {
-						clef *theclef = ((clef *) curObj->object);
+			clef *theclef = ((clef *) curObj->object);
             g_string_append_printf (selection, _("a Clef Change object.\n"));   
-						if (theclef->directives) 
+			if (theclef->directives) 
 							{
 								selection = g_string_append (selection, _("Attached to the Clef Change:"));
 								append_directives_information (selection, theclef->directives);
 							}
+			if (curObj->isinvisible)
+                           selection = g_string_append (selection, _("This clef change is non-printing, it just affects the display.\n"));
+
           }
           break;
         case TIMESIG:
@@ -1756,7 +1805,7 @@ write_status (DenemoGUI * gui)
           {
             chord *thechord = ((chord *) curObj->object);
             selection = g_strdup_printf ("%s%s%s%s%s%s%s%s%s",
-                                         thechord->notes ? (g_list_length (thechord->notes) > 1 ? "Chord " : "Note ") : "Rest ", thechord->slur_begin_p ? ", begin slur" : "", thechord->slur_end_p ? ", end slur" : "", thechord->is_tied ? ", tied" : "", thechord->crescendo_begin_p ? ", begin cresc." : "", thechord->crescendo_end_p ? ", end cresc." : "", thechord->diminuendo_begin_p ? ", begin dim." : "", thechord->diminuendo_end_p ? ", end dim." : "", thechord->is_grace ? ", grace note" : "");
+                                         thechord->notes ? (g_list_length (thechord->notes) > 1 ? _("Chord ") : _("Note ")) : _("Rest "), thechord->slur_begin_p ? _(", begin slur") : "", thechord->slur_end_p ? _(", end slur") : "", thechord->is_tied ? _(", tied") : "", thechord->crescendo_begin_p ? _(", begin cresc.") : "", thechord->crescendo_end_p ? _(", end cresc.") : "", thechord->diminuendo_begin_p ? _(", begin dim.") : "", thechord->diminuendo_end_p ? _(", end dim.") : "", thechord->is_grace ? _(", grace note") : "");
             if (thechord->notes)
               {
                 GList *g;
@@ -1780,44 +1829,70 @@ write_status (DenemoGUI * gui)
           break;
 
         case TUPOPEN:
-          selection = g_strdup_printf ("Tuplet %d/%d", ((tupopen *) curObj->object)->numerator, ((tupopen *) curObj->object)->denominator);
+          selection = g_strdup_printf (_("Tuplet %d/%d"), ((tupopen *) curObj->object)->numerator, ((tupopen *) curObj->object)->denominator);
           break;
         case TUPCLOSE:
-          selection = g_strdup_printf ("End tuplet");
+          selection = g_strdup_printf (_("End tuplet"));
           break;
         case CLEF:
-          selection = g_strdup_printf ("clef change");
+          selection = g_strdup_printf (_("Clef change"));
           break;
         case TIMESIG:
-          selection = g_strdup_printf ("time signature change");
+          selection = g_strdup_printf (_("Time signature change"));
           break;
         case KEYSIG:
-          selection = g_strdup_printf ("key signature change");
+          selection = g_strdup_printf (_("Key signature change"));
           break;
         case STEMDIRECTIVE:
-          selection = g_strdup_printf ("stem directive: %s", ((stemdirective *) curObj->object)->type == DENEMO_STEMDOWN ? "stem down" : ((stemdirective *) curObj->object)->type == DENEMO_STEMUP ? "stem up" : "normal stemming");
+          selection = g_strdup_printf (_("Stem directive: %s"), ((stemdirective *) curObj->object)->type == DENEMO_STEMDOWN ? _("stem down") : ((stemdirective *) curObj->object)->type == DENEMO_STEMUP ? _("stem up") : _("normal stemming"));
           break;
         case DYNAMIC:
-          selection = g_strdup_printf ("Dynamic: %s", ((dynamic *) curObj->object)->type->str);
+          selection = g_strdup_printf (_("Dynamic: %s"), ((dynamic *) curObj->object)->type->str);
           break;
 
         case LILYDIRECTIVE:
           {
             DenemoDirective *directive = (DenemoDirective *) curObj->object;
-            selection = g_strdup_printf ("Directive:(%.20s) %.20s%.50s", directive->tag ? directive->tag->str : "Unknown Tag", directive->x ? "Not all layouts" : directive->y ? "Only for one Layout" : "", directive->postfix ? directive->postfix->str : directive->prefix ? directive->prefix->str : directive->graphic_name ? directive->graphic_name->str : directive->display ? directive->display->str : "empty");
+            selection = g_strdup_printf (_("Directive:(%.20s) %.20s%.50s"), directive->tag ? directive->tag->str : _("Unknown Tag"), directive->x ? _("Not all layouts") : directive->y ? _("Only for one Layout") : "", directive->postfix ? directive->postfix->str : directive->prefix ? directive->prefix->str : directive->graphic_name ? directive->graphic_name->str : directive->display ? directive->display->str : "empty");
           }
           break;
         default:
-          selection = g_strdup_printf ("Cursor on a unknown object");
+          selection = g_strdup_printf (_("Cursor on an unknown object"));
         }
     }
   else
-    selection = g_strdup_printf ("Cursor not on any object");
+    selection = g_strdup_printf (_("Cursor not on any object"));
 
   GString *status = g_string_new (_("Movement"));
-
   gint index = g_list_index (gui->movements, gui->si);
-  g_string_printf (status, "%s %d: %s: ", enshift_string (gui->si->pending_enshift), index + 1, selection);
+  const gchar *dur ="";
+  switch (get_prevailing_duration())
+  {
+	  case 0: dur = NOTE0;
+	  break;
+	  case 1: dur = NOTE1;
+	  break;
+	  case 2: dur = NOTE2;
+	  break;
+	  case 3: dur = NOTE3;
+	  break;
+	  case 4: dur = NOTE4;
+	  break;
+	  case 5: dur = NOTE5;
+	  break;
+	  case 6: dur = NOTE6;
+	  break;
+	  case 7: dur = NOTE7;
+	  break;
+	  case 8: dur = NOTE8;
+	  break;
+	 
+	  
+  }
+  g_string_printf (status, "%s%s %d: %s: ", enshift_string (gui->si->pending_enshift), dur, index + 1, selection);
+  
+
+  
   if (gui->si->smf && (gui->si->smfsync == gui->si->changecount) && Denemo.prefs.playback_controls)
     g_string_append_printf (status, _("%d min %.2f sec %.2f %.2f"), minutes, seconds, early, late);
   else
@@ -2356,11 +2431,16 @@ find_dir_for_file(gchar* filename, gchar* dirs[])
 
   for(i = 0; dirs[i]; i++)
   {
+	  //g_print("Searching %s\n", dirs[i]);
     if(!dir)
     {
       path = g_build_filename (dirs[i], filename, NULL);
       if(g_file_test (path, G_FILE_TEST_EXISTS))
-        dir = g_strdup(dirs[i]);
+        {
+		 dir = g_strdup(dirs[i]);
+			//g_print("Found file %s\n", path);
+		} else
+			//g_print("No file %s\n", path);
       g_free(path);
     }
     g_free(dirs[i]);
@@ -2394,12 +2474,12 @@ get_local_dir(DenemoDirectory dir)
 {
   switch(dir)
   {
-    case COMMANDS:   return COMMANDS_DIR;
-    case UI:         return UI_DIR;
-    case SOUNDFONTS: return SOUNDFONTS_DIR;
-    case PIXMAPS:    return PIXMAPS_DIR;
-    case FONTS:      return FONTS_DIR;
-    case LOCALE:     return LOCALE_DIR;
+    case DENEMO_DIR_COMMANDS:   return COMMANDS_DIR;
+    case DENEMO_DIR_UI:         return UI_DIR;
+    case DENEMO_DIR_SOUNDFONTS: return SOUNDFONTS_DIR;
+    case DENEMO_DIR_PIXMAPS:    return PIXMAPS_DIR;
+    case DENEMO_DIR_FONTS:      return FONTS_DIR;
+    case DENEMO_DIR_LOCALE:     return LOCALE_DIR;
     default:         return NULL;
   }
 }
@@ -2409,20 +2489,18 @@ get_system_dir(DenemoDirectory dir)
 {
   switch(dir)
   {
-    case COMMANDS:
-    case UI:
-    case SOUNDFONTS:
-    case FONTS:
+    case DENEMO_DIR_COMMANDS:
+    case DENEMO_DIR_UI:
+    case DENEMO_DIR_SOUNDFONTS:
+    case DENEMO_DIR_FONTS:
       return g_build_filename(get_system_data_dir (), get_local_dir(dir), NULL);
-#ifndef G_OS_WIN32
-    case PIXMAPS:
-      return g_build_filename(get_system_data_dir (), "..", PIXMAPS_DIR, NULL);
+    case DENEMO_DIR_PIXMAPS:
+      return g_build_filename(get_system_data_dir (), PIXMAPS_DIR, NULL);
       break;
-#endif
-    case LOCALE:
+    case DENEMO_DIR_LOCALE:
       return g_strdup(get_system_locale_dir ());
       break;
-    case BIN:
+    case DENEMO_DIR_BIN:
       return g_strdup(get_system_bin_dir ());
       break;
     default:
@@ -2466,16 +2544,15 @@ get_executable_dir ()
  *  - in the system directory
  **/
 gchar*
-find(DenemoDirectory dir, gchar* filename)
+find_denemo_file (DenemoDirectory dir, gchar* filename)
 {
-  gchar* current = g_get_current_dir ();
+  //g_print("find_denemo_file called with %d and %s\n", dir, filename);
   gchar* dirs[] = {
-    //g_build_filename(current, get_local_dir (dir), NULL),
-    g_build_filename(get_executable_dir (), "..", get_local_dir (dir), NULL),
-    g_build_filename(get_user_data_dir(), get_local_dir (dir), NULL),
-    g_build_filename(get_system_dir(dir), NULL),
+    g_build_filename(get_executable_dir (TRUE), "..", get_local_dir (dir), NULL),
+    g_build_filename(get_user_data_dir (TRUE), get_local_dir (dir), NULL),
+    g_strdup(get_system_dir(dir)),
     NULL
   };
-  g_free(current);
+ 
   return find_path_for_file (filename, dirs);
 }
