@@ -35,6 +35,9 @@
 #define FONT "Sans 9"
 #define TIMESIGFONT "Sans 24"
 
+const gchar *get_user_data_dir (gboolean create);
+
+const gchar *locateprintdir (void);
 /* Adds a callback that processes the "activate" signal coming from
  * a widget */
 
@@ -291,5 +294,5 @@ void write_input_status();
 enum clefs cleftypefromname (gchar * str);
 gchar* find_dir_for_file(gchar* filename, gchar* dirs[]);
 gchar* find_path_for_file(gchar* filename, gchar* dirs[]);
-gchar* find(DenemoDirectory dir, gchar* filename);
+gchar* find_denemo_file (DenemoDirectory dir, gchar* filename);
 #endif /* UTILS_H */
