@@ -37,6 +37,9 @@
 #include "print.h"
 #include "barline.h"
 #include "runsilent.h"
+#include "palettes.h"
+#include "palettestorage.h"
+
 #include "libguile.h"
 
 #define EXTRA_ACCELS "extra.accels"
